@@ -1,4 +1,4 @@
-# -------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 # Copyright (c) Microsoft.  All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,14 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-# --------------------------------------------------------------------------
-from ._constants import (
+#--------------------------------------------------------------------------
+
+from .._constants import (
     __author__,
     __version__,
-    DEFAULT_X_MS_VERSION,
+    X_MS_VERSION,
 )
-from .cloudstorageaccount import CloudStorageAccount
-from .models import (
+
+from ..models import (
     RetentionPolicy,
     Logging,
     Metrics,
@@ -29,16 +30,9 @@ from .models import (
     Services,
     AccountPermissions,
     Protocol,
-    ServiceStats,
-    GeoReplication,
-    LocationMode,
-    RetryContext,
 )
-from .retry import (
-    ExponentialRetry,
-    LinearRetry,
-    no_retry,
-)
-from .sharedaccesssignature import (
+
+from ..cloudstorageaccount import CloudStorageAccount
+from ..sharedaccesssignature import (
     SharedAccessSignature,
 )
