@@ -1,4 +1,4 @@
-# -------------------------------------------------------------------------
+﻿#-------------------------------------------------------------------------
 # Copyright (c) Microsoft.  All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,14 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-# --------------------------------------------------------------------------
-from ..common._common_conversion import _str
-from ..common._error import (
+#--------------------------------------------------------------------------
+from time import time
+from wsgiref.handlers import format_date_time
+from .._error import (
     _validate_not_none,
     _ERROR_START_END_NEEDED_FOR_MD5,
     _ERROR_RANGE_TOO_LARGE_FOR_MD5,
 )
-
+from .._common_conversion import _str
 
 def _get_path(share_name=None, directory_name=None, file_name=None):
     '''
@@ -49,27 +50,22 @@ def _get_path(share_name=None, directory_name=None, file_name=None):
     else:
         return '/'
 
-
-def _validate_and_format_range_headers(request, start_range, end_range, start_range_required=True,
-                                       end_range_required=True, check_content_md5=False):
-    # If end range is provided, start range must be provided
-    if start_range_required or end_range is not None:
+def _validate_and_format_range_headers(request, start_range, end_range, start_range_required=True, end_range_required=True, check_content_md5=False):
+    request.headers = request.headers or []
+    if start_range_required == True:
         _validate_not_none('start_range', start_range)
-    if end_range_required:
+    if end_range_required == True:
         _validate_not_none('end_range', end_range)
+    if end_range_required == True or end_range is not None:
+        _validate_not_none('end_range', end_range)        
+        request.headers.append(('x-ms-range', "bytes={0}-{1}".format(start_range, end_range)))
+    else:
+        request.headers.append(('x-ms-range', "bytes={0}-".format(start_range)))
 
-    # Format based on whether end_range is present
-    request.headers = request.headers or {}
-    if end_range is not None:
-        request.headers['x-ms-range'] = 'bytes={0}-{1}'.format(start_range, end_range)
-    elif start_range is not None:
-        request.headers['x-ms-range'] = 'bytes={0}-'.format(start_range)
-
-    # Content MD5 can only be provided for a complete range less than 4MB in size
-    if check_content_md5:
+    if check_content_md5 == True:
         if start_range is None or end_range is None:
             raise ValueError(_ERROR_START_END_NEEDED_FOR_MD5)
         if end_range - start_range > 4 * 1024 * 1024:
             raise ValueError(_ERROR_RANGE_TOO_LARGE_FOR_MD5)
 
-        request.headers['x-ms-range-get-content-md5'] = 'true'
+        request.headers.append(('x-ms-range-get-content-md5', 'true'))
\ No newline at end of file
