@@ -1,7 +1,16 @@
 # -------------------------------------------------------------------------
-# Copyright (c) Microsoft Corporation. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
+# Copyright (c) Microsoft.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 # --------------------------------------------------------------------------
 import sys
 from os import path
@@ -68,9 +77,9 @@ class AppendBlobService(BaseBlobService):
     '''
     MAX_BLOCK_SIZE = 4 * 1024 * 1024
 
-    def __init__(self, account_name=None, account_key=None, sas_token=None, is_emulated=False,
-                 protocol=DEFAULT_PROTOCOL, endpoint_suffix=SERVICE_HOST_BASE, custom_domain=None, request_session=None,
-                 connection_string=None, socket_timeout=None, token_credential=None):
+    def __init__(self, account_name=None, account_key=None, sas_token=None,
+                 is_emulated=False, protocol=DEFAULT_PROTOCOL, endpoint_suffix=SERVICE_HOST_BASE,
+                 custom_domain=None, request_session=None, connection_string=None, socket_timeout=None):
         '''
         :param str account_name:
             The storage account name. This is used to authenticate requests 
@@ -109,22 +118,18 @@ class AppendBlobService(BaseBlobService):
         :param int socket_timeout:
             If specified, this will override the default socket timeout. The timeout specified is in seconds.
             See DEFAULT_SOCKET_TIMEOUT in _constants.py for the default value.
-        :param token_credential:
-            A token credential used to authenticate HTTPS requests. The token value
-            should be updated before its expiration.
-        :type `~..common.TokenCredential`
         '''
         self.blob_type = _BlobTypes.AppendBlob
         super(AppendBlobService, self).__init__(
             account_name, account_key, sas_token, is_emulated, protocol, endpoint_suffix,
-            custom_domain, request_session, connection_string, socket_timeout, token_credential)
+            custom_domain, request_session, connection_string, socket_timeout)
 
     def create_blob(self, container_name, blob_name, content_settings=None,
                     metadata=None, lease_id=None,
                     if_modified_since=None, if_unmodified_since=None,
                     if_match=None, if_none_match=None, timeout=None):
         '''
-        Creates a blob or overrides an existing blob. Use if_none_match=* to
+        Creates a blob or overrides an existing blob. Use if_match=* to
         prevent overriding an existing blob. 
 
         See create_blob_from_* for high level
@@ -290,9 +295,7 @@ class AppendBlobService(BaseBlobService):
 
     def append_blob_from_path(
             self, container_name, blob_name, file_path, validate_content=False,
-            maxsize_condition=None, progress_callback=None, lease_id=None, timeout=None,
-            if_modified_since=None, if_unmodified_since=None, if_match=None,
-            if_none_match=None):
+            maxsize_condition=None, progress_callback=None, lease_id=None, timeout=None):
         '''
         Appends to the content of an existing blob from a file path, with automatic
         chunking and progress notifications.
@@ -327,27 +330,6 @@ class AppendBlobService(BaseBlobService):
             The timeout parameter is expressed in seconds. This method may make 
             multiple calls to the Azure service and the timeout will apply to 
             each call individually.
-        :param datetime if_modified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only
-            if the resource has been modified since the specified time.
-        :param datetime if_unmodified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only if
-            the resource has not been modified since the specified date/time.
-        :param str if_match:
-            An ETag value, or the wildcard character (*). Specify this header to perform
-            the operation only if the resource's ETag matches the value specified.
-        :param str if_none_match:
-            An ETag value, or the wildcard character (*). Specify this header
-            to perform the operation only if the resource's ETag does not match
-            the value specified. Specify the wildcard character (*) to perform
-            the operation only if the resource does not exist, and fail the
-            operation if it does exist.
         :return: ETag and last modified properties for the Append Blob
         :rtype: :class:`~azure.storage.blob.models.ResourceProperties`
         '''
@@ -367,17 +349,12 @@ class AppendBlobService(BaseBlobService):
                 maxsize_condition=maxsize_condition,
                 progress_callback=progress_callback,
                 lease_id=lease_id,
-                timeout=timeout,
-                if_modified_since=if_modified_since,
-                if_unmodified_since=if_unmodified_since,
-                if_match=if_match,
-                if_none_match=if_none_match)
+                timeout=timeout)
 
     def append_blob_from_bytes(
             self, container_name, blob_name, blob, index=0, count=None,
             validate_content=False, maxsize_condition=None, progress_callback=None,
-            lease_id=None, timeout=None, if_modified_since=None, if_unmodified_since=None, if_match=None,
-            if_none_match=None):
+            lease_id=None, timeout=None):
         '''
         Appends to the content of an existing blob from an array of bytes, with
         automatic chunking and progress notifications.
@@ -417,27 +394,6 @@ class AppendBlobService(BaseBlobService):
             The timeout parameter is expressed in seconds. This method may make 
             multiple calls to the Azure service and the timeout will apply to 
             each call individually.
-        :param datetime if_modified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only
-            if the resource has been modified since the specified time.
-        :param datetime if_unmodified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only if
-            the resource has not been modified since the specified date/time.
-        :param str if_match:
-            An ETag value, or the wildcard character (*). Specify this header to perform
-            the operation only if the resource's ETag matches the value specified.
-        :param str if_none_match:
-            An ETag value, or the wildcard character (*). Specify this header
-            to perform the operation only if the resource's ETag does not match
-            the value specified. Specify the wildcard character (*) to perform
-            the operation only if the resource does not exist, and fail the
-            operation if it does exist.
         :return: ETag and last modified properties for the Append Blob
         :rtype: :class:`~azure.storage.blob.models.ResourceProperties`
         '''
@@ -466,17 +422,12 @@ class AppendBlobService(BaseBlobService):
             maxsize_condition=maxsize_condition,
             lease_id=lease_id,
             progress_callback=progress_callback,
-            timeout=timeout,
-            if_modified_since=if_modified_since,
-            if_unmodified_since=if_unmodified_since,
-            if_match=if_match,
-            if_none_match=if_none_match)
+            timeout=timeout)
 
     def append_blob_from_text(
             self, container_name, blob_name, text, encoding='utf-8',
             validate_content=False, maxsize_condition=None, progress_callback=None,
-            lease_id=None, timeout=None, if_modified_since=None, if_unmodified_since=None, if_match=None,
-            if_none_match=None):
+            lease_id=None, timeout=None):
         '''
         Appends to the content of an existing blob from str/unicode, with
         automatic chunking and progress notifications.
@@ -513,27 +464,6 @@ class AppendBlobService(BaseBlobService):
             The timeout parameter is expressed in seconds. This method may make 
             multiple calls to the Azure service and the timeout will apply to 
             each call individually.
-        :param datetime if_modified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only
-            if the resource has been modified since the specified time.
-        :param datetime if_unmodified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only if
-            the resource has not been modified since the specified date/time.
-        :param str if_match:
-            An ETag value, or the wildcard character (*). Specify this header to perform
-            the operation only if the resource's ETag matches the value specified.
-        :param str if_none_match:
-            An ETag value, or the wildcard character (*). Specify this header
-            to perform the operation only if the resource's ETag does not match
-            the value specified. Specify the wildcard character (*) to perform
-            the operation only if the resource does not exist, and fail the
-            operation if it does exist.
         :return: ETag and last modified properties for the Append Blob
         :rtype: :class:`~azure.storage.blob.models.ResourceProperties`
         '''
@@ -556,17 +486,12 @@ class AppendBlobService(BaseBlobService):
             maxsize_condition=maxsize_condition,
             lease_id=lease_id,
             progress_callback=progress_callback,
-            timeout=timeout,
-            if_modified_since=if_modified_since,
-            if_unmodified_since=if_unmodified_since,
-            if_match=if_match,
-            if_none_match=if_none_match)
+            timeout=timeout)
 
     def append_blob_from_stream(
             self, container_name, blob_name, stream, count=None,
             validate_content=False, maxsize_condition=None, progress_callback=None,
-            lease_id=None, timeout=None, if_modified_since=None, if_unmodified_since=None, if_match=None,
-            if_none_match=None):
+            lease_id=None, timeout=None):
         '''
         Appends to the content of an existing blob from a file/stream, with
         automatic chunking and progress notifications.
@@ -604,27 +529,6 @@ class AppendBlobService(BaseBlobService):
             The timeout parameter is expressed in seconds. This method may make 
             multiple calls to the Azure service and the timeout will apply to 
             each call individually.
-        :param datetime if_modified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only
-            if the resource has been modified since the specified time.
-        :param datetime if_unmodified_since:
-            A DateTime value. Azure expects the date value passed in to be UTC.
-            If timezone is included, any non-UTC datetime will be converted to UTC.
-            If a date is passed in without timezone info, it is assumed to be UTC.
-            Specify this header to perform the operation only if
-            the resource has not been modified since the specified date/time.
-        :param str if_match:
-            An ETag value, or the wildcard character (*). Specify this header to perform
-            the operation only if the resource's ETag matches the value specified.
-        :param str if_none_match:
-            An ETag value, or the wildcard character (*). Specify this header
-            to perform the operation only if the resource's ETag does not match
-            the value specified. Specify the wildcard character (*) to perform
-            the operation only if the resource does not exist, and fail the
-            operation if it does exist.
         :return: ETag and last modified properties for the Append Blob
         :rtype: :class:`~azure.storage.blob.models.ResourceProperties`
         '''
@@ -651,11 +555,7 @@ class AppendBlobService(BaseBlobService):
             uploader_class=_AppendBlobChunkUploader,
             maxsize_condition=maxsize_condition,
             timeout=timeout,
-            resource_properties=resource_properties,
-            if_modified_since=if_modified_since,
-            if_unmodified_since=if_unmodified_since,
-            if_match=if_match,
-            if_none_match=if_none_match
+            resource_properties=resource_properties
         )
 
         return resource_properties
