@@ -1,7 +1,16 @@
 # -------------------------------------------------------------------------
-# Copyright (c) Microsoft Corporation. All rights reserved.
-# Licensed under the MIT License. See License.txt in the project root for
-# license information.
+# Copyright (c) Microsoft.  All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 # --------------------------------------------------------------------------
 
 import sys
@@ -39,7 +48,6 @@ from .models import (
     _OperationContext,
 )
 from .retry import ExponentialRetry
-from io import UnsupportedOperation
 
 
 class StorageClient(object):
@@ -105,7 +113,6 @@ class StorageClient(object):
         self.account_name = connection_params.account_name
         self.account_key = connection_params.account_key
         self.sas_token = connection_params.sas_token
-        self.token_credential = connection_params.token_credential
         self.is_emulated = connection_params.is_emulated
 
         self.primary_endpoint = connection_params.primary_endpoint
@@ -216,15 +223,6 @@ class StorageClient(object):
         '''
         operation_context = operation_context or _OperationContext()
         retry_context = RetryContext()
-        retry_context.is_emulated = self.is_emulated
-
-        # if request body is a stream, we need to remember its current position in case retries happen
-        if hasattr(request.body, 'read'):
-            try:
-                retry_context.body_position = request.body.tell()
-            except (AttributeError, UnsupportedOperation):
-                # if body position cannot be obtained, then retries will not work
-                pass
 
         # Apply the appropriate host based on the location mode
         self._apply_host(request, operation_context, retry_context)
@@ -245,13 +243,7 @@ class StorageClient(object):
                     # callback. This also ensures retry policies with long back offs 
                     # will work as it resets the time sensitive headers.
                     _add_date_header(request)
-
-                    try:
-                        # request can be signed individually
-                        self.authentication.sign_request(request)
-                    except AttributeError:
-                        # session can also be signed
-                        self.request_session = self.authentication.signed_session(self.request_session)
+                    self.authentication.sign_request(request)
 
                     # Set the request context
                     retry_context.request = request
@@ -373,7 +365,4 @@ class StorageClient(object):
                 # this is the first request of that operation. Set the location to 
                 # be used for subsequent requests in the operation.
                 if operation_context.location_lock and not operation_context.host_location:
-                    # note: to cover the emulator scenario, the host_location is grabbed
-                    # from request.host_locations(which includes the dev account name)
-                    # instead of request.host(which at this point no longer includes the dev account name)
-                    operation_context.host_location = {retry_context.location_mode: request.host_locations[retry_context.location_mode]}
+                    operation_context.host_location = {retry_context.location_mode: request.host}
