@@ -1,16 +1,7 @@
 # -------------------------------------------------------------------------
-# Copyright (c) Microsoft.  All rights reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#   http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Copyright (c) Microsoft Corporation. All rights reserved.
+# Licensed under the MIT License. See License.txt in the project root for
+# license information.
 # --------------------------------------------------------------------------
 import sys
 
@@ -23,6 +14,7 @@ from ._constants import (
     SERVICE_HOST_BASE,
     DEFAULT_PROTOCOL,
     DEV_ACCOUNT_NAME,
+    DEV_ACCOUNT_SECONDARY_NAME,
     DEV_ACCOUNT_KEY,
     DEV_BLOB_HOST,
     DEV_QUEUE_HOST,
@@ -49,14 +41,16 @@ _CONNECTION_ENDPOINTS_SECONDARY = {
     'file': 'FileSecondaryEndpoint',
 }
 
+
 class _ServiceParameters(object):
-    def __init__(self, service, account_name=None, account_key=None, sas_token=None, 
+    def __init__(self, service, account_name=None, account_key=None, sas_token=None, token_credential=None,
                  is_emulated=False, protocol=DEFAULT_PROTOCOL, endpoint_suffix=SERVICE_HOST_BASE, 
                  custom_domain=None, custom_domain_secondary=None):
 
         self.account_name = account_name
         self.account_key = account_key
         self.sas_token = sas_token
+        self.token_credential = token_credential
         self.protocol = protocol or DEFAULT_PROTOCOL
         self.is_emulated = is_emulated
 
@@ -66,9 +60,10 @@ class _ServiceParameters(object):
 
             # Only set the account key if a sas_token is not present to allow sas to be used with the emulator
             self.account_key = DEV_ACCOUNT_KEY if not self.sas_token else None
+            emulator_endpoint = _EMULATOR_ENDPOINTS[service] if custom_domain is None else custom_domain
 
-            self.primary_endpoint = '{}/{}'.format(_EMULATOR_ENDPOINTS[service], self.account_name)
-            self.secondary_endpoint = '{}/{}-secondary'.format(_EMULATOR_ENDPOINTS[service], self.account_name)
+            self.primary_endpoint = '{}/{}'.format(emulator_endpoint, DEV_ACCOUNT_NAME)
+            self.secondary_endpoint = '{}/{}'.format(emulator_endpoint, DEV_ACCOUNT_SECONDARY_NAME)
         else:
             # Strip whitespace from the key
             if self.account_key:
@@ -108,18 +103,21 @@ class _ServiceParameters(object):
                     self.secondary_endpoint = None
 
     @staticmethod
-    def get_service_parameters(service, account_name=None, account_key=None, sas_token=None, is_emulated=None,
-                               protocol=None, endpoint_suffix=None, custom_domain=None, request_session=None,
-                               connection_string=None, socket_timeout=None):
+    def get_service_parameters(service, account_name=None, account_key=None, sas_token=None, token_credential= None,
+                               is_emulated=None, protocol=None, endpoint_suffix=None, custom_domain=None,
+                               request_session=None, connection_string=None, socket_timeout=None):
         if connection_string:
             params = _ServiceParameters._from_connection_string(connection_string, service)
         elif is_emulated:
-            params = _ServiceParameters(service, is_emulated=True)
+            params = _ServiceParameters(service, is_emulated=True, custom_domain=custom_domain)
         elif account_name:
+            if protocol.lower() != 'https' and token_credential is not None:
+                raise ValueError("Token credential is only supported with HTTPS.")
             params = _ServiceParameters(service,
                                         account_name=account_name,
                                         account_key=account_key,
                                         sas_token=sas_token,
+                                        token_credential=token_credential,
                                         is_emulated=is_emulated,
                                         protocol=protocol,
                                         endpoint_suffix=endpoint_suffix,
