@@ -6,15 +6,10 @@
 
 import sys
 import threading
-import time
-
 import warnings
 from io import BytesIO
-from typing import Iterator
-
-import requests
-from azure.core.exceptions import HttpResponseError, ServiceResponseError
 
+from azure.core.exceptions import HttpResponseError
 from azure.core.tracing.common import with_current_context
 from ._shared.encryption import decrypt_blob
 from ._shared.request_handlers import validate_and_format_range_headers
@@ -48,9 +43,10 @@ def process_range_and_offset(start_range, end_range, length, encryption):
 def process_content(data, start_offset, end_offset, encryption):
     if data is None:
         raise ValueError("Response cannot be None.")
-
-    content = b"".join(list(data))
-
+    try:
+        content = b"".join(list(data))
+    except Exception as error:
+        raise HttpResponseError(message="Download stream interrupted.", response=data.response, error=error)
     if content and encryption.get("key") is not None or encryption.get("resolver") is not None:
         try:
             return decrypt_blob(
@@ -192,29 +188,19 @@ class _ChunkDownloader(object):  # pylint: disable=too-many-instance-attributes
                 check_content_md5=self.validate_content
             )
 
-            retry_active = True
-            retry_total = 3
-            while retry_active:
-                try:
-                    _, response = self.client.download(
-                        range=range_header,
-                        range_get_content_md5=range_validation,
-                        validate_content=self.validate_content,
-                        data_stream_total=self.total_size,
-                        download_stream_current=self.progress_total,
-                        **self.request_options
-                    )
-                except HttpResponseError as error:
-                    process_storage_error(error)
+            try:
+                _, response = self.client.download(
+                    range=range_header,
+                    range_get_content_md5=range_validation,
+                    validate_content=self.validate_content,
+                    data_stream_total=self.total_size,
+                    download_stream_current=self.progress_total,
+                    **self.request_options
+                )
+            except HttpResponseError as error:
+                process_storage_error(error)
 
-                try:
-                    chunk_data = process_content(response, offset[0], offset[1], self.encryption_options)
-                    retry_active = False
-                except (requests.exceptions.ChunkedEncodingError, requests.exceptions.ConnectionError) as error:
-                    retry_total -= 1
-                    if retry_total <= 0:
-                        raise ServiceResponseError(error, error=error)
-                    time.sleep(1)
+            chunk_data = process_content(response, offset[0], offset[1], self.encryption_options)
 
             # This makes sure that if_match is set so that we can validate
             # that subsequent downloads are to an unmodified blob
@@ -227,9 +213,8 @@ class _ChunkDownloader(object):  # pylint: disable=too-many-instance-attributes
 class _ChunkIterator(object):
     """Async iterator for chunks in blob download stream."""
 
-    def __init__(self, size, content, downloader, chunk_size):
+    def __init__(self, size, content, downloader):
         self.size = size
-        self._chunk_size = chunk_size
         self._current_content = content
         self._iter_downloader = downloader
         self._iter_chunks = None
@@ -246,39 +231,21 @@ class _ChunkIterator(object):
         if self._complete:
             raise StopIteration("Download complete")
         if not self._iter_downloader:
-            # cut the data obtained from initial GET into chunks
-            if len(self._current_content) > self._chunk_size:
-                return self._get_chunk_data()
+            # If no iterator was supplied, the download completed with
+            # the initial GET, so we just return that data
             self._complete = True
             return self._current_content
 
         if not self._iter_chunks:
             self._iter_chunks = self._iter_downloader.get_chunk_offsets()
-
-        # initial GET result still has more than _chunk_size bytes of data
-        if len(self._current_content) >= self._chunk_size:
-            return self._get_chunk_data()
-
-        try:
+        else:
             chunk = next(self._iter_chunks)
-            self._current_content += self._iter_downloader.yield_chunk(chunk)
-        except StopIteration as e:
-            self._complete = True
-            if self._current_content:
-                return self._current_content
-            raise e
+            self._current_content = self._iter_downloader.yield_chunk(chunk)
 
-        # the current content from the first get is still there but smaller than chunk size
-        # therefore we want to make sure its also included
-        return self._get_chunk_data()
+        return self._current_content
 
     next = __next__  # Python 2 compatibility.
 
-    def _get_chunk_data(self):
-        chunk_data = self._current_content[: self._chunk_size]
-        self._current_content = self._current_content[self._chunk_size:]
-        return chunk_data
-
 
 class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attributes
     """A streaming object to download from Azure Storage.
@@ -291,7 +258,7 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         The properties of the blob being downloaded. If only a range of the data is being
         downloaded, this will be reflected in the properties.
     :ivar int size:
-        The size of the total data in the stream. This will be the byte range if specified,
+        The size of the total data in the stream. This will be the byte range if speficied,
         otherwise the total size of the blob.
     """
 
@@ -367,6 +334,16 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         # TODO: Set to the stored MD5 when the service returns this
         self.properties.content_md5 = None
 
+        if self.size == 0:
+            self._current_content = b""
+        else:
+            self._current_content = process_content(
+                self._response,
+                self._initial_offset[0],
+                self._initial_offset[1],
+                self._encryption_options
+            )
+
     def __len__(self):
         return self.size
 
@@ -379,71 +356,51 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
             check_content_md5=self._validate_content
         )
 
-        retry_active = True
-        retry_total = 3
-        while retry_active:
-            try:
-                location_mode, response = self._clients.blob.download(
-                    range=range_header,
-                    range_get_content_md5=range_validation,
-                    validate_content=self._validate_content,
-                    data_stream_total=None,
-                    download_stream_current=0,
-                    **self._request_options
-                )
+        try:
+            location_mode, response = self._clients.blob.download(
+                range=range_header,
+                range_get_content_md5=range_validation,
+                validate_content=self._validate_content,
+                data_stream_total=None,
+                download_stream_current=0,
+                **self._request_options
+            )
 
-                # Check the location we read from to ensure we use the same one
-                # for subsequent requests.
-                self._location_mode = location_mode
+            # Check the location we read from to ensure we use the same one
+            # for subsequent requests.
+            self._location_mode = location_mode
 
-                # Parse the total file size and adjust the download size if ranges
-                # were specified
-                self._file_size = parse_length_from_content_range(response.properties.content_range)
-                if self._end_range is not None:
-                    # Use the end range index unless it is over the end of the file
-                    self.size = min(self._file_size, self._end_range - self._start_range + 1)
-                elif self._start_range is not None:
-                    self.size = self._file_size - self._start_range
-                else:
-                    self.size = self._file_size
+            # Parse the total file size and adjust the download size if ranges
+            # were specified
+            self._file_size = parse_length_from_content_range(response.properties.content_range)
+            if self._end_range is not None:
+                # Use the end range index unless it is over the end of the file
+                self.size = min(self._file_size, self._end_range - self._start_range + 1)
+            elif self._start_range is not None:
+                self.size = self._file_size - self._start_range
+            else:
+                self.size = self._file_size
 
-            except HttpResponseError as error:
-                if self._start_range is None and error.response.status_code == 416:
-                    # Get range will fail on an empty file. If the user did not
-                    # request a range, do a regular get request in order to get
-                    # any properties.
-                    try:
-                        _, response = self._clients.blob.download(
-                            validate_content=self._validate_content,
-                            data_stream_total=0,
-                            download_stream_current=0,
-                            **self._request_options
-                        )
-                    except HttpResponseError as error:
-                        process_storage_error(error)
-
-                    # Set the download size to empty
-                    self.size = 0
-                    self._file_size = 0
-                else:
+        except HttpResponseError as error:
+            if self._start_range is None and error.response.status_code == 416:
+                # Get range will fail on an empty file. If the user did not
+                # request a range, do a regular get request in order to get
+                # any properties.
+                try:
+                    _, response = self._clients.blob.download(
+                        validate_content=self._validate_content,
+                        data_stream_total=0,
+                        download_stream_current=0,
+                        **self._request_options
+                    )
+                except HttpResponseError as error:
                     process_storage_error(error)
 
-            try:
-                if self.size == 0:
-                    self._current_content = b""
-                else:
-                    self._current_content = process_content(
-                        response,
-                        self._initial_offset[0],
-                        self._initial_offset[1],
-                        self._encryption_options
-                    )
-                retry_active = False
-            except (requests.exceptions.ChunkedEncodingError, requests.exceptions.ConnectionError) as error:
-                retry_total -= 1
-                if retry_total <= 0:
-                    raise ServiceResponseError(error, error=error)
-                time.sleep(1)
+                # Set the download size to empty
+                self.size = 0
+                self._file_size = 0
+            else:
+                process_storage_error(error)
 
         # get page ranges to optimize downloading sparse page blob
         if response.properties.blob_type == 'PageBlob':
@@ -469,20 +426,6 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         return response
 
     def chunks(self):
-        # type: () -> Iterator[bytes]
-        """Iterate over chunks in the download stream.
-
-        :rtype: Iterator[bytes]
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/blob_samples_hello_world.py
-                :start-after: [START download_a_blob_in_chunk]
-                :end-before: [END download_a_blob_in_chunk]
-                :language: python
-                :dedent: 12
-                :caption: Download a blob using chunks().
-        """
         if self.size == 0 or self._download_complete:
             iter_downloader = None
         else:
@@ -508,14 +451,12 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         return _ChunkIterator(
             size=self.size,
             content=self._current_content,
-            downloader=iter_downloader,
-            chunk_size=self._config.max_chunk_get_size)
+            downloader=iter_downloader)
 
     def readall(self):
         """Download the contents of this blob.
 
         This operation is blocking until all data is downloaded.
-
         :rtype: bytes or str
         """
         stream = BytesIO()
@@ -609,11 +550,11 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         )
         if parallel:
             import concurrent.futures
-            with concurrent.futures.ThreadPoolExecutor(self._max_concurrency) as executor:
-                list(executor.map(
-                        with_current_context(downloader.process_chunk),
-                        downloader.get_chunk_offsets()
-                    ))
+            executor = concurrent.futures.ThreadPoolExecutor(self._max_concurrency)
+            list(executor.map(
+                    with_current_context(downloader.process_chunk),
+                    downloader.get_chunk_offsets()
+                ))
         else:
             for chunk in downloader.get_chunk_offsets():
                 downloader.process_chunk(chunk)
