@@ -3,15 +3,13 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=invalid-overridden-method
+
 import functools
-import warnings
 from typing import (  # pylint: disable=unused-import
     Union, Optional, Any, Iterable, Dict, List,
     TYPE_CHECKING
 )
 
-from azure.core.exceptions import HttpResponseError
 from azure.core.tracing.decorator import distributed_trace
 from azure.core.pipeline import AsyncPipeline
 from azure.core.tracing.decorator_async import distributed_trace_async
@@ -23,18 +21,21 @@ from .._shared.base_client_async import AsyncStorageAccountHostsMixin, AsyncTran
 from .._shared.response_handlers import return_response_headers, process_storage_error
 from .._shared.parser import _to_utc_datetime
 from .._shared.response_handlers import parse_to_internal_user_delegation_key
+from .._generated import VERSION
 from .._generated.aio import AzureBlobStorage
-from .._generated.models import StorageServiceProperties, KeyInfo
+from .._generated.models import StorageErrorException, StorageServiceProperties, KeyInfo
 from .._blob_service_client import BlobServiceClient as BlobServiceClientBase
 from ._container_client_async import ContainerClient
 from ._blob_client_async import BlobClient
 from .._models import ContainerProperties
 from .._deserialize import service_stats_deserialize, service_properties_deserialize
 from .._serialize import get_api_version
-from ._models import ContainerPropertiesPaged, FilteredBlobPaged
+from ._models import ContainerPropertiesPaged
 
 if TYPE_CHECKING:
     from datetime import datetime
+    from azure.core.pipeline.transport import HttpTransport
+    from azure.core.pipeline.policies import HTTPPolicy
     from .._shared.models import AccountSasPermissions, ResourceTypes, UserDelegationKey
     from ._lease_async import BlobLeaseClient
     from .._models import (
@@ -62,14 +63,12 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         authenticated with a SAS token.
     :param credential:
         The credentials with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential from azure.core.credentials, an account
+        account URL already has a SAS token. The value can be a SAS token string, an account
         shared access key, or an instance of a TokenCredentials class from azure.identity.
-        If the resource URI already contains a SAS token, this will be ignored in favor of an explicit credential
-        - except in the case of AzureSasCredential, where the conflicting SAS tokens will raise a ValueError.
+        If the URL already has a SAS token, specifying an explicit credential will take priority.
     :keyword str api_version:
-        The Storage API version to use for requests. Default value is the most recent service version that is
-        compatible with the current SDK. Setting to an older version may result in reduced feature compatibility.
+        The Storage API version to use for requests. Default value is '2019-07-07'.
+        Setting to an older version may result in reduced feature compatibility.
 
         .. versionadded:: 12.2.0
 
@@ -77,7 +76,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         The hostname of the secondary endpoint.
     :keyword int max_block_size: The maximum chunk size for uploading a block blob in chunks.
         Defaults to 4*1024*1024, or 4MB.
-    :keyword int max_single_put_size: If the blob size is less than or equal max_single_put_size, then the blob will be
+    :keyword int max_single_put_size: If the blob size is less than max_single_put_size, then the blob will be
         uploaded with only one http PUT request. If the blob size is larger than max_single_put_size,
         the blob will be uploaded in chunks. Defaults to 64*1024*1024, or 64MB.
     :keyword int min_large_block_upload_threshold: The minimum chunk size required to use the memory efficient
@@ -117,8 +116,9 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             account_url,
             credential=credential,
             **kwargs)
-        self._client = AzureBlobStorage(self.url, base_url=self.url, pipeline=self._pipeline)
-        self._client._config.version = get_api_version(kwargs)  # pylint: disable=protected-access
+        self._client = AzureBlobStorage(url=self.url, pipeline=self._pipeline)
+        self._client._config.version = get_api_version(kwargs, VERSION)  # pylint: disable=protected-access
+        self._loop = kwargs.get('loop', None)
 
     @distributed_trace_async
     async def get_user_delegation_key(self, key_start_time,  # type: datetime
@@ -145,7 +145,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             user_delegation_key = await self._client.service.get_user_delegation_key(key_info=key_info,
                                                                                      timeout=timeout,
                                                                                      **kwargs)  # type: ignore
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
         return parse_to_internal_user_delegation_key(user_delegation_key)  # type: ignore
@@ -172,7 +172,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         """
         try:
             return await self._client.service.get_account_info(cls=return_response_headers, **kwargs) # type: ignore
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace_async
@@ -215,7 +215,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             stats = await self._client.service.get_statistics( # type: ignore
                 timeout=timeout, use_location=LocationMode.SECONDARY, **kwargs)
             return service_stats_deserialize(stats)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace_async
@@ -243,7 +243,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         try:
             service_props = await self._client.service.get_properties(timeout=timeout, **kwargs)
             return service_properties_deserialize(service_props)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace_async
@@ -304,11 +304,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
                 :dedent: 12
                 :caption: Setting service properties for the blob service.
         """
-        if all(parameter is None for parameter in [
-                    analytics_logging, hour_metrics, minute_metrics, cors,
-                    target_version, delete_retention_policy, static_website]):
-            raise ValueError("set_service_properties should be called with at least one parameter")
-
         props = StorageServiceProperties(
             logging=analytics_logging,
             hour_metrics=hour_metrics,
@@ -321,7 +316,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         timeout = kwargs.pop('timeout', None)
         try:
             await self._client.service.set_properties(props, timeout=timeout, **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -342,13 +337,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
         :param bool include_metadata:
             Specifies that container metadata to be returned in the response.
             The default value is `False`.
-        :keyword bool include_deleted:
-            Specifies that deleted containers to be returned in the response. This is for container restore enabled
-            account. The default value is `False`.
-            .. versionadded:: 12.4.0
-        :keyword bool include_system:
-            Flag specifying that system containers should be included.
-            .. versionadded:: 12.10.0
         :keyword int results_per_page:
             The maximum number of container names to retrieve per API
             call. If the request does not specify the server will return up to 5,000 items.
@@ -366,13 +354,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
                 :dedent: 16
                 :caption: Listing the containers in the blob service.
         """
-        include = ['metadata'] if include_metadata else []
-        include_deleted = kwargs.pop('include_deleted', None)
-        if include_deleted:
-            include.append("deleted")
-        include_system = kwargs.pop('include_system', None)
-        if include_system:
-            include.append("system")
+        include = 'metadata' if include_metadata else None
         timeout = kwargs.pop('timeout', None)
         results_per_page = kwargs.pop('results_per_page', None)
         command = functools.partial(
@@ -388,37 +370,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             page_iterator_class=ContainerPropertiesPaged
         )
 
-    @distributed_trace
-    def find_blobs_by_tags(self, filter_expression, **kwargs):
-        # type: (str, **Any) -> AsyncItemPaged[FilteredBlob]
-        """The Filter Blobs operation enables callers to list blobs across all
-        containers whose tags match a given search expression.  Filter blobs
-        searches across all containers within a storage account but can be
-        scoped within the expression to a single container.
-
-        :param str filter_expression:
-            The expression to find blobs whose tags matches the specified condition.
-            eg. "\"yourtagname\"='firsttag' and \"yourtagname2\"='secondtag'"
-            To specify a container, eg. "@container='containerName' and \"Name\"='C'"
-        :keyword int results_per_page:
-            The max result per page when paginating.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :returns: An iterable (auto-paging) response of BlobProperties.
-        :rtype: ~azure.core.async_paging.AsyncItemPaged[~azure.storage.blob.FilteredBlob]
-        """
-
-        results_per_page = kwargs.pop('results_per_page', None)
-        timeout = kwargs.pop('timeout', None)
-        command = functools.partial(
-            self._client.service.filter_blobs,
-            where=filter_expression,
-            timeout=timeout,
-            **kwargs)
-        return AsyncItemPaged(
-            command, results_per_page=results_per_page,
-            page_iterator_class=FilteredBlobPaged)
-
     @distributed_trace_async
     async def create_container(
             self, name,  # type: str
@@ -527,68 +478,6 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             timeout=timeout,
             **kwargs)
 
-    @distributed_trace_async
-    async def _rename_container(self, name, new_name, **kwargs):
-        # type: (str, str, **Any) -> ContainerClient
-        """Renames a container.
-
-        Operation is successful only if the source container exists.
-
-        :param str name:
-            The name of the container to rename.
-        :param str new_name:
-            The new container name the user wants to rename to.
-        :keyword lease:
-            Specify this to perform only if the lease ID given
-            matches the active lease ID of the source container.
-        :paramtype lease: ~azure.storage.blob.BlobLeaseClient or str
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :rtype: ~azure.storage.blob.ContainerClient
-        """
-        renamed_container = self.get_container_client(new_name)
-        lease = kwargs.pop('lease', None)
-        try:
-            kwargs['source_lease_id'] = lease.id  # type: str
-        except AttributeError:
-            kwargs['source_lease_id'] = lease
-        try:
-            await renamed_container._client.container.rename(name, **kwargs)   # pylint: disable = protected-access
-            return renamed_container
-        except HttpResponseError as error:
-            process_storage_error(error)
-
-    @distributed_trace_async
-    async def undelete_container(self, deleted_container_name, deleted_container_version, **kwargs):
-        # type: (str, str, **Any) -> ContainerClient
-        """Restores soft-deleted container.
-
-        Operation will only be successful if used within the specified number of days
-        set in the delete retention policy.
-
-        .. versionadded:: 12.4.0
-            This operation was introduced in API version '2019-12-12'.
-
-        :param str deleted_container_name:
-            Specifies the name of the deleted container to restore.
-        :param str deleted_container_version:
-            Specifies the version of the deleted container to restore.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :rtype: ~azure.storage.blob.aio.ContainerClient
-        """
-        new_name = kwargs.pop('new_name', None)
-        if new_name:
-            warnings.warn("`new_name` is no longer supported.", DeprecationWarning)
-        container = self.get_container_client(new_name or deleted_container_name)
-        try:
-            await container._client.container.restore(deleted_container_name=deleted_container_name, # pylint: disable = protected-access
-                                                      deleted_container_version=deleted_container_version,
-                                                      timeout=kwargs.pop('timeout', None), **kwargs)
-            return container
-        except HttpResponseError as error:
-            process_storage_error(error)
-
     def get_container_client(self, container):
         # type: (Union[ContainerProperties, str]) -> ContainerClient
         """Get a client to interact with the specified container.
@@ -624,7 +513,7 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             credential=self.credential, api_version=self.api_version, _configuration=self._config,
             _pipeline=_pipeline, _location_mode=self._location_mode, _hosts=self._hosts,
             require_encryption=self.require_encryption, key_encryption_key=self.key_encryption_key,
-            key_resolver_function=self.key_resolver_function)
+            key_resolver_function=self.key_resolver_function, loop=self._loop)
 
     def get_blob_client(
             self, container,  # type: Union[ContainerProperties, str]
@@ -679,4 +568,4 @@ class BlobServiceClient(AsyncStorageAccountHostsMixin, BlobServiceClientBase):
             credential=self.credential, api_version=self.api_version, _configuration=self._config,
             _pipeline=_pipeline, _location_mode=self._location_mode, _hosts=self._hosts,
             require_encryption=self.require_encryption, key_encryption_key=self.key_encryption_key,
-            key_resolver_function=self.key_resolver_function)
+            key_resolver_function=self.key_resolver_function, loop=self._loop)
