@@ -3,26 +3,11 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-from typing import ( # pylint: disable=unused-import
-    Any, Dict, Optional, Type, TypeVar, Union,
-    TYPE_CHECKING)
-
-try:
-    from urllib.parse import quote, unquote
-except ImportError:
-    from urllib2 import quote, unquote # type: ignore
-from azure.core.pipeline import Pipeline
-from ._deserialize import deserialize_dir_properties
-from ._shared.base_client import TransportWrapper, parse_connection_str
+from ._shared.base_client import parse_connection_str
 from ._data_lake_file_client import DataLakeFileClient
-from ._models import DirectoryProperties, FileProperties
+from ._models import DirectoryProperties
 from ._path_client import PathClient
 
-if TYPE_CHECKING:
-    from datetime import datetime
-
-ClassType = TypeVar("ClassType")
-
 
 class DataLakeDirectoryClient(PathClient):
     """A client to interact with the DataLake directory, even if the directory may not yet exist.
@@ -46,31 +31,31 @@ class DataLakeDirectoryClient(PathClient):
     :type directory_name: str
     :param credential:
         The credentials with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-        an account shared access key, or an instance of a TokenCredentials class from azure.identity.
-        If the resource URI already contains a SAS token, this will be ignored in favor of an explicit credential
-        - except in the case of AzureSasCredential, where the conflicting SAS tokens will raise a ValueError.
-        If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-        should be the storage account key.
-    :keyword str api_version:
-        The Storage API version to use for requests. Default value is the most recent service version that is
-        compatible with the current SDK. Setting to an older version may result in reduced feature compatibility.
+        account URL already has a SAS token. The value can be a SAS token string, and account
+        shared access key, or an instance of a TokenCredentials class from azure.identity.
+        If the URL already has a SAS token, specifying an explicit credential will take priority.
 
     .. admonition:: Example:
 
-        .. literalinclude:: ../samples/datalake_samples_instantiate_client.py
-            :start-after: [START instantiate_directory_client_from_conn_str]
-            :end-before: [END instantiate_directory_client_from_conn_str]
+        .. literalinclude:: ../samples/test_datalake_authentication_samples.py
+            :start-after: [START create_datalake_service_client]
+            :end-before: [END create_datalake_service_client]
             :language: python
-            :dedent: 4
-            :caption: Creating the DataLakeServiceClient from connection string.
+            :dedent: 8
+            :caption: Creating the DataLakeServiceClient with account url and credential.
+
+        .. literalinclude:: ../samples/test_datalake_authentication_samples.py
+            :start-after: [START create_datalake_service_client_oauth]
+            :end-before: [END create_datalake_service_client_oauth]
+            :language: python
+            :dedent: 8
+            :caption: Creating the DataLakeServiceClient with Azure Identity credentials.
     """
     def __init__(
         self, account_url,  # type: str
         file_system_name,  # type: str
         directory_name,  # type: str
-        credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
+        credential=None,  # type: Optional[Any]
         **kwargs  # type: Any
     ):
         # type: (...) -> None
@@ -79,88 +64,66 @@ class DataLakeDirectoryClient(PathClient):
 
     @classmethod
     def from_connection_string(
-            cls,  # type: Type[ClassType]
-            conn_str,  # type: str
+            cls, conn_str,  # type: str
             file_system_name,  # type: str
             directory_name,  # type: str
-            credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
+            credential=None,  # type: Optional[Any]
             **kwargs  # type: Any
-        ):  # type: (...) -> ClassType
+        ):  # type: (...) -> DataLakeDirectoryClient
         """
         Create DataLakeDirectoryClient from a Connection String.
 
         :param str conn_str:
             A connection string to an Azure Storage account.
-        :param file_system_name:
-            The name of file system to interact with.
+        :param file_system_name: The name of file system to interact with.
         :type file_system_name: str
-        :param directory_name:
-            The name of directory to interact with. The directory is under file system.
+        :param directory_name: The name of directory to interact with. The directory is under file system.
         :type directory_name: str
         :param credential:
             The credentials with which to authenticate. This is optional if the
             account URL already has a SAS token, or the connection string already has shared
-            access key values. The value can be a SAS token string,
-            an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-            an account shared access key, or an instance of a TokenCredentials class from azure.identity.
+            access key values. The value can be a SAS token string, and account shared access
+            key, or an instance of a TokenCredentials class from azure.identity.
             Credentials provided here will take precedence over those in the connection string.
-            If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-            should be the storage account key.
-        :return: a DataLakeDirectoryClient
-        :rtype: ~azure.storage.filedatalake.DataLakeDirectoryClient
+        :return a DataLakeDirectoryClient
+        :rtype ~azure.storage.filedatalake.DataLakeDirectoryClient
         """
-        account_url, _, credential = parse_connection_str(conn_str, credential, 'dfs')
+        account_url, secondary, credential = parse_connection_str(conn_str, credential, 'dfs')
+        if 'secondary_hostname' not in kwargs:
+            kwargs['secondary_hostname'] = secondary
         return cls(
             account_url, file_system_name=file_system_name, directory_name=directory_name,
             credential=credential, **kwargs)
 
-    def create_directory(self, metadata=None,  # type: Optional[Dict[str, str]]
+    def create_directory(self, content_settings=None,  # type: Optional[ContentSettings]
+                         metadata=None,  # type: Optional[Dict[str, str]]
                          **kwargs):
         # type: (...) -> Dict[str, Union[str, datetime]]
         """
         Create a new directory.
 
-        :param metadata:
-            Name-value pairs associated with the file as metadata.
-        :type metadata: dict(str, str)
-        :keyword ~azure.storage.filedatalake.ContentSettings content_settings:
+        :param ~azure.storage.filedatalake.ContentSettings content_settings:
             ContentSettings object used to set path properties.
+        :param metadata:
+            Name-value pairs associated with the blob as metadata.
+        :type metadata: dict(str, str)
         :keyword lease:
-            Required if the file has an active lease. Value can be a DataLakeLeaseClient object
+            Required if the blob has an active lease. Value can be a DataLakeLeaseClient object
             or the lease ID as a string.
         :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
-        :keyword str umask:
-            Optional and only valid if Hierarchical Namespace is enabled for the account.
+        :keyword str umask: Optional and only valid if Hierarchical Namespace is enabled for the account.
             When creating a file or directory and the parent folder does not have a default ACL,
             the umask restricts the permissions of the file or directory to be created.
             The resulting permission is given by p & ^u, where p is the permission and u is the umask.
             For example, if p is 0777 and u is 0057, then the resulting permission is 0720.
             The default permission is 0777 for a directory and 0666 for a file. The default umask is 0027.
             The umask must be specified in 4-digit octal notation (e.g. 0766).
-        :keyword str owner:
-            The owner of the file or directory.
-        :keyword str group:
-            The owning group of the file or directory.
-        :keyword str acl:
-            Sets POSIX access control rights on files and directories. The value is a
-            comma-separated list of access control entries. Each access control entry (ACE) consists of a
-            scope, a type, a user or group identifier, and permissions in the format
-            "[scope:][type]:[id]:[permissions]".
-        :keyword str lease_id:
-            Proposed lease ID, in a GUID string format. The DataLake service returns
-            400 (Invalid request) if the proposed lease ID is not in the correct format.
-        :keyword int lease_duration:
-            Specifies the duration of the lease, in seconds, or negative one
-            (-1) for a lease that never expires. A non-infinite lease can be
-            between 15 and 60 seconds. A lease duration cannot be changed
-            using renew or change.
-        :keyword str permissions:
-            Optional and only valid if Hierarchical Namespace
-            is enabled for the account. Sets POSIX access permissions for the file
-            owner, the file owning group, and others. Each class may be granted
-            read, write, or execute permission.  The sticky bit is also supported.
-            Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
-            supported.
+        :keyword str permissions: Optional and only valid if Hierarchical Namespace
+         is enabled for the account. Sets POSIX access permissions for the file
+         owner, the file owning group, and others. Each class may be granted
+         read, write, or execute permission.  The sticky bit is also supported.
+         Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
+         supported.
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -178,24 +141,11 @@ class DataLakeDirectoryClient(PathClient):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword ~azure.storage.filedatalake.CustomerProvidedEncryptionKey cpk:
-            Encrypts the data on the service-side with the given key.
-            Use of customer-provided keys must be done over HTTPS.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
-        :return: A dictionary of response headers.
-        :rtype: Dict[str, Union[str, datetime]]
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/datalake_samples_directory.py
-                :start-after: [START create_directory]
-                :end-before: [END create_directory]
-                :language: python
-                :dedent: 8
-                :caption: Create directory.
+        :return: response dict (Etag and last modified).
         """
-        return self._create('directory', metadata=metadata, **kwargs)
+        return self._create('directory', content_settings=content_settings, metadata=metadata, **kwargs)
 
     def delete_directory(self, **kwargs):
         # type: (...) -> None
@@ -203,9 +153,9 @@ class DataLakeDirectoryClient(PathClient):
         Marks the specified directory for deletion.
 
         :keyword lease:
-            Required if the file has an active lease. Value can be a LeaseClient object
+            Required if the blob has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.blob.LeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -226,17 +176,8 @@ class DataLakeDirectoryClient(PathClient):
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: None
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/datalake_samples_directory.py
-                :start-after: [START delete_directory]
-                :end-before: [END delete_directory]
-                :language: python
-                :dedent: 4
-                :caption: Delete directory.
         """
-        return self._delete(recursive=True, **kwargs)
+        return self._delete(**kwargs)
 
     def get_directory_properties(self, **kwargs):
         # type: (**Any) -> DirectoryProperties
@@ -246,7 +187,7 @@ class DataLakeDirectoryClient(PathClient):
         :keyword lease:
             Required if the directory or file has an active lease. Value can be a DataLakeLeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -264,53 +205,53 @@ class DataLakeDirectoryClient(PathClient):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword ~azure.storage.filedatalake.CustomerProvidedEncryptionKey cpk:
-            Decrypts the data on the service-side with the given key.
-            Use of customer-provided keys must be done over HTTPS.
-            Required if the directory was created with a customer-provided key.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :rtype: DirectoryProperties
 
         .. admonition:: Example:
 
-            .. literalinclude:: ../samples/datalake_samples_directory.py
-                :start-after: [START get_directory_properties]
-                :end-before: [END get_directory_properties]
+            .. literalinclude:: ../tests/test_blob_samples_common.py
+                :start-after: [START get_blob_properties]
+                :end-before: [END get_blob_properties]
                 :language: python
-                :dedent: 4
+                :dedent: 8
                 :caption: Getting the properties for a file/directory.
         """
-        return self._get_path_properties(cls=deserialize_dir_properties, **kwargs)  # pylint: disable=protected-access
+        blob_properties = self._get_path_properties(**kwargs)
+        return DirectoryProperties._from_blob_properties(blob_properties)  # pylint: disable=protected-access
 
-    def exists(self, **kwargs):
-        # type: (**Any) -> bool
-        """
-        Returns True if a directory exists and returns False otherwise.
-
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :returns: boolean
-        """
-        return self._exists(**kwargs)
-
-    def rename_directory(self, new_name, **kwargs):
-        # type: (str, **Any) -> DataLakeDirectoryClient
+    def rename_directory(self, rename_destination, **kwargs):
+        # type: (**Any) -> DataLakeDirectoryClient
         """
         Rename the source directory.
 
-        :param str new_name:
-            the new directory name the user want to rename to.
+        :param str rename_destination: the new directory name the user want to rename to.
             The value must have the following format: "{filesystem}/{directory}/{subdirectory}".
-        :keyword source_lease:
-            A lease ID for the source path. If specified,
-            the source path must have an active lease and the leaase ID must
-            match.
-        :paramtype source_lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :keyword source_lease: A lease ID for the source path. If specified,
+         the source path must have an active lease and the leaase ID must
+         match.
+        :keyword source_lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :param ~azure.storage.filedatalake.ContentSettings content_settings:
+            ContentSettings object used to set path properties.
         :keyword lease:
             Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :keyword str umask: Optional and only valid if Hierarchical Namespace is enabled for the account.
+            When creating a file or directory and the parent folder does not have a default ACL,
+            the umask restricts the permissions of the file or directory to be created.
+            The resulting permission is given by p & ^u, where p is the permission and u is the umask.
+            For example, if p is 0777 and u is 0057, then the resulting permission is 0720.
+            The default permission is 0777 for a directory and 0666 for a file. The default umask is 0027.
+            The umask must be specified in 4-digit octal notation (e.g. 0766).
+        :keyword permissions: Optional and only valid if Hierarchical Namespace
+         is enabled for the account. Sets POSIX access permissions for the file
+         owner, the file owning group, and others. Each class may be granted
+         read, write, or execute permission.  The sticky bit is also supported.
+         Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
+         supported.
+        :type permissions: str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -348,40 +289,23 @@ class DataLakeDirectoryClient(PathClient):
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: DataLakeDirectoryClient
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/datalake_samples_directory.py
-                :start-after: [START rename_directory]
-                :end-before: [END rename_directory]
-                :language: python
-                :dedent: 4
-                :caption: Rename the source directory.
         """
-        new_name = new_name.strip('/')
-        new_file_system = new_name.split('/')[0]
-        new_path_and_token = new_name[len(new_file_system):].strip('/').split('?')
-        new_path = new_path_and_token[0]
-        try:
-            new_dir_sas = new_path_and_token[1] or self._query_str.strip('?')
-        except IndexError:
-            if not self._raw_credential and new_file_system != self.file_system_name:
-                raise ValueError("please provide the sas token for the new file")
-            if not self._raw_credential and new_file_system == self.file_system_name:
-                new_dir_sas = self._query_str.strip('?')
+        rename_destination = rename_destination.strip('/')
+        new_file_system = rename_destination.split('/')[0]
+        path = rename_destination[len(new_file_system):]
 
         new_directory_client = DataLakeDirectoryClient(
-            "{}://{}".format(self.scheme, self.primary_hostname), new_file_system, directory_name=new_path,
-            credential=self._raw_credential or new_dir_sas,
-            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline)
-        new_directory_client._rename_path(  # pylint: disable=protected-access
-            '/{}/{}{}'.format(quote(unquote(self.file_system_name)),
-                              quote(unquote(self.path_name)),
-                              self._query_str),
-            **kwargs)
+            self.url, new_file_system, directory_name=path, credential=self._raw_credential,
+            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline,
+            _location_mode=self._location_mode, require_encryption=self.require_encryption,
+            key_encryption_key=self.key_encryption_key,
+            key_resolver_function=self.key_resolver_function)
+        new_directory_client._rename_path('/'+self.file_system_name+'/'+self.path_name,  # pylint: disable=protected-access
+                                          **kwargs)
         return new_directory_client
 
     def create_sub_directory(self, sub_directory,  # type: Union[DirectoryProperties, str]
+                             content_settings=None,  # type: Optional[ContentSettings]
                              metadata=None,  # type: Optional[Dict[str, str]]
                              **kwargs):
         # type: (...) -> DataLakeDirectoryClient
@@ -392,47 +316,27 @@ class DataLakeDirectoryClient(PathClient):
             The directory with which to interact. This can either be the name of the directory,
             or an instance of DirectoryProperties.
         :type sub_directory: str or ~azure.storage.filedatalake.DirectoryProperties
-        :param metadata:
-            Name-value pairs associated with the file as metadata.
-        :type metadata: dict(str, str)
-        :keyword ~azure.storage.filedatalake.ContentSettings content_settings:
+        :param ~azure.storage.filedatalake.ContentSettings content_settings:
             ContentSettings object used to set path properties.
-        :keyword lease:
-            Required if the file has an active lease. Value can be a DataLakeLeaseClient object
+        :param metadata:
+            Name-value pairs associated with the blob as metadata.
+        :type metadata: dict(str, str)
+        :keyword ~azure.storage.filedatalake.DataLakeLeaseClient or str lease:
+            Required if the blob has an active lease. Value can be a DataLakeLeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
-        :keyword str umask:
-            Optional and only valid if Hierarchical Namespace is enabled for the account.
+        :keyword str umask: Optional and only valid if Hierarchical Namespace is enabled for the account.
             When creating a file or directory and the parent folder does not have a default ACL,
             the umask restricts the permissions of the file or directory to be created.
             The resulting permission is given by p & ^u, where p is the permission and u is the umask.
             For example, if p is 0777 and u is 0057, then the resulting permission is 0720.
             The default permission is 0777 for a directory and 0666 for a file. The default umask is 0027.
             The umask must be specified in 4-digit octal notation (e.g. 0766).
-        :keyword str owner:
-            The owner of the file or directory.
-        :keyword str group:
-            The owning group of the file or directory.
-        :keyword str acl:
-            Sets POSIX access control rights on files and directories. The value is a
-            comma-separated list of access control entries. Each access control entry (ACE) consists of a
-            scope, a type, a user or group identifier, and permissions in the format
-            "[scope:][type]:[id]:[permissions]".
-        :keyword str lease_id:
-            Proposed lease ID, in a GUID string format. The DataLake service returns
-            400 (Invalid request) if the proposed lease ID is not in the correct format.
-        :keyword int lease_duration:
-            Specifies the duration of the lease, in seconds, or negative one
-            (-1) for a lease that never expires. A non-infinite lease can be
-            between 15 and 60 seconds. A lease duration cannot be changed
-            using renew or change.
-        :keyword str permissions:
-            Optional and only valid if Hierarchical Namespace
-            is enabled for the account. Sets POSIX access permissions for the file
-            owner, the file owning group, and others. Each class may be granted
-            read, write, or execute permission.  The sticky bit is also supported.
-            Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
-            supported.
+        :keyword str permissions: Optional and only valid if Hierarchical Namespace
+         is enabled for the account. Sets POSIX access permissions for the file
+         owner, the file owning group, and others. Each class may be granted
+         read, write, or execute permission.  The sticky bit is also supported.
+         Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
+         supported.
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -450,15 +354,12 @@ class DataLakeDirectoryClient(PathClient):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword ~azure.storage.filedatalake.CustomerProvidedEncryptionKey cpk:
-            Encrypts the data on the service-side with the given key.
-            Use of customer-provided keys must be done over HTTPS.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: DataLakeDirectoryClient for the subdirectory.
         """
         subdir = self.get_sub_directory_client(sub_directory)
-        subdir.create_directory(metadata=metadata, **kwargs)
+        subdir.create_directory(content_settings=content_settings, metadata=metadata, **kwargs)
         return subdir
 
     def delete_sub_directory(self, sub_directory,  # type: Union[DirectoryProperties, str]
@@ -472,9 +373,9 @@ class DataLakeDirectoryClient(PathClient):
             or an instance of DirectoryProperties.
         :type sub_directory: str or ~azure.storage.filedatalake.DirectoryProperties
         :keyword lease:
-            Required if the file has an active lease. Value can be a LeaseClient object
+            Required if the blob has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.blob.LeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -513,52 +414,24 @@ class DataLakeDirectoryClient(PathClient):
         :keyword ~azure.storage.filedatalake.ContentSettings content_settings:
             ContentSettings object used to set path properties.
         :keyword metadata:
-            Name-value pairs associated with the file as metadata.
+            Name-value pairs associated with the blob as metadata.
         :type metadata: dict(str, str)
-        :keyword lease:
-            Required if the file has an active lease. Value can be a DataLakeLeaseClient object
+        :keyword ~azure.storage.filedatalake.DataLakeLeaseClient or str lease:
+            Required if the blob has an active lease. Value can be a DataLakeLeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
-        :keyword str umask:
-            Optional and only valid if Hierarchical Namespace is enabled for the account.
+        :keyword str umask: Optional and only valid if Hierarchical Namespace is enabled for the account.
             When creating a file or directory and the parent folder does not have a default ACL,
             the umask restricts the permissions of the file or directory to be created.
             The resulting permission is given by p & ^u, where p is the permission and u is the umask.
             For example, if p is 0777 and u is 0057, then the resulting permission is 0720.
             The default permission is 0777 for a directory and 0666 for a file. The default umask is 0027.
             The umask must be specified in 4-digit octal notation (e.g. 0766).
-        :keyword str owner:
-            The owner of the file or directory.
-        :keyword str group:
-            The owning group of the file or directory.
-        :keyword str acl:
-            Sets POSIX access control rights on files and directories. The value is a
-            comma-separated list of access control entries. Each access control entry (ACE) consists of a
-            scope, a type, a user or group identifier, and permissions in the format
-            "[scope:][type]:[id]:[permissions]".
-        :keyword str lease_id:
-            Proposed lease ID, in a GUID string format. The DataLake service returns
-            400 (Invalid request) if the proposed lease ID is not in the correct format.
-        :keyword int lease_duration:
-            Specifies the duration of the lease, in seconds, or negative one
-            (-1) for a lease that never expires. A non-infinite lease can be
-            between 15 and 60 seconds. A lease duration cannot be changed
-            using renew or change.
-        :keyword expires_on:
-            The time to set the file to expiry.
-            If the type of expires_on is an int, expiration time will be set
-            as the number of milliseconds elapsed from creation time.
-            If the type of expires_on is datetime, expiration time will be set
-            absolute to the time provided. If no time zone info is provided, this
-            will be interpreted as UTC.
-        :paramtype expires_on: datetime or int
-        :keyword str permissions:
-            Optional and only valid if Hierarchical Namespace
-            is enabled for the account. Sets POSIX access permissions for the file
-            owner, the file owning group, and others. Each class may be granted
-            read, write, or execute permission.  The sticky bit is also supported.
-            Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
-            supported.
+        :keyword str permissions: Optional and only valid if Hierarchical Namespace
+         is enabled for the account. Sets POSIX access permissions for the file
+         owner, the file owning group, and others. Each class may be granted
+         read, write, or execute permission.  The sticky bit is also supported.
+         Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
+         supported.
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -576,9 +449,6 @@ class DataLakeDirectoryClient(PathClient):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword ~azure.storage.filedatalake.CustomerProvidedEncryptionKey cpk:
-            Encrypts the data on the service-side with the given key.
-            Use of customer-provided keys must be done over HTTPS.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: DataLakeFileClient
@@ -599,21 +469,28 @@ class DataLakeDirectoryClient(PathClient):
             or an instance of FileProperties. eg. directory/subdirectory/file
         :type file: str or ~azure.storage.filedatalake.FileProperties
         :returns: A DataLakeFileClient.
-        :rtype: ~azure.storage.filedatalake.DataLakeFileClient
+        :rtype: ~azure.storage.filedatalake..DataLakeFileClient
+
+        .. admonition:: Example:
+
+            .. literalinclude:: ../samples/test_datalake_service_samples.py
+                :start-after: [START bsc_get_file_client]
+                :end-before: [END bsc_get_file_client]
+                :language: python
+                :dedent: 12
+                :caption: Getting the file client to interact with a specific file.
         """
         try:
-            file_path = file.get('name')
+            file_path = file.name
         except AttributeError:
-            file_path = self.path_name + '/' + str(file)
+            file_path = self.path_name + '/' + file
 
-        _pipeline = Pipeline(
-            transport=TransportWrapper(self._pipeline._transport), # pylint: disable = protected-access
-            policies=self._pipeline._impl_policies # pylint: disable = protected-access
-        )
         return DataLakeFileClient(
             self.url, self.file_system_name, file_path=file_path, credential=self._raw_credential,
-            api_version=self.api_version,
-            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline)
+            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline,
+            _location_mode=self._location_mode, require_encryption=self.require_encryption,
+            key_encryption_key=self.key_encryption_key,
+            key_resolver_function=self.key_resolver_function)
 
     def get_sub_directory_client(self, sub_directory  # type: Union[DirectoryProperties, str]
                                  ):
@@ -628,17 +505,24 @@ class DataLakeDirectoryClient(PathClient):
         :type sub_directory: str or ~azure.storage.filedatalake.DirectoryProperties
         :returns: A DataLakeDirectoryClient.
         :rtype: ~azure.storage.filedatalake.DataLakeDirectoryClient
+
+        .. admonition:: Example:
+
+            .. literalinclude:: ../samples/test_datalake_service_samples.py
+                :start-after: [START bsc_get_directory_client]
+                :end-before: [END bsc_get_directory_client]
+                :language: python
+                :dedent: 12
+                :caption: Getting the directory client to interact with a specific directory.
         """
         try:
-            subdir_path = sub_directory.get('name')
+            subdir_path = sub_directory.name
         except AttributeError:
-            subdir_path = self.path_name + '/' + str(sub_directory)
+            subdir_path = self.path_name + '/' + sub_directory
 
-        _pipeline = Pipeline(
-            transport=TransportWrapper(self._pipeline._transport), # pylint: disable = protected-access
-            policies=self._pipeline._impl_policies # pylint: disable = protected-access
-        )
         return DataLakeDirectoryClient(
             self.url, self.file_system_name, directory_name=subdir_path, credential=self._raw_credential,
-            api_version=self.api_version,
-            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline)
+            _hosts=self._hosts, _configuration=self._config, _pipeline=self._pipeline,
+            _location_mode=self._location_mode, require_encryption=self.require_encryption,
+            key_encryption_key=self.key_encryption_key,
+            key_resolver_function=self.key_resolver_function)
