@@ -3,22 +3,14 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-from azure.multiapi.storagev2.blob.v2020_02_10._serialize import _get_match_headers  # pylint: disable=protected-access
+from azure.storage.blob._serialize import _get_match_headers  # pylint: disable=protected-access
 from ._shared import encode_base64
 from ._generated.models import ModifiedAccessConditions, PathHTTPHeaders, \
     SourceModifiedAccessConditions, LeaseAccessConditions
 
 
 def convert_dfs_url_to_blob_url(dfs_account_url):
-    return dfs_account_url.replace('.dfs.', '.blob.', 1)
-
-
-def convert_datetime_to_rfc1123(date):
-    weekday = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"][date.weekday()]
-    month = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
-             "Oct", "Nov", "Dec"][date.month - 1]
-    return "%s, %02d %s %04d %02d:%02d:%02d GMT" % (weekday, date.day, month,
-                                                    date.year, date.hour, date.minute, date.second)
+    return dfs_account_url.replace('dfs.core.windows.net', 'blob.core.windows.net', 1)
 
 
 def add_metadata_headers(metadata=None):
