@@ -3,7 +3,6 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=too-many-instance-attributes
 
 from enum import Enum
 
@@ -25,7 +24,6 @@ class StorageErrorCode(str, Enum):
     account_is_disabled = "AccountIsDisabled"
     authentication_failed = "AuthenticationFailed"
     authorization_failure = "AuthorizationFailure"
-    no_authentication_information = "NoAuthenticationInformation"
     condition_headers_not_supported = "ConditionHeadersNotSupported"
     condition_not_met = "ConditionNotMet"
     empty_metadata_key = "EmptyMetadataKey"
@@ -311,8 +309,6 @@ class AccountSasPermissions(object):
         Permits write permissions to the specified resource type.
     :param bool delete:
         Valid for Container and Object resource types, except for queue messages.
-    :param bool delete_previous_version:
-        Delete the previous blob version for the versioning enabled storage account.
     :param bool list:
         Valid for Service and Container resource types only.
     :param bool add:
@@ -325,47 +321,25 @@ class AccountSasPermissions(object):
         Valid for the following Object resource types only: queue messages.
     :param bool process:
         Valid for the following Object resource type only: queue messages.
-    :keyword bool tag:
-        To enable set or get tags on the blobs in the container.
-    :keyword bool filter_by_tags:
-        To enable get blobs by tags, this should be used together with list permission.
-    :keyword bool set_immutability_policy:
-        To enable operations related to set/delete immutability policy.
-        To get immutability policy, you just need read permission.
-    :keyword bool permanent_delete:
-        To enable permanent delete on the blob is permitted.
-        Valid for Object resource type of Blob only.
     """
-    def __init__(self, read=False, write=False, delete=False,
-                 list=False,  # pylint: disable=redefined-builtin
-                 add=False, create=False, update=False, process=False, delete_previous_version=False, **kwargs):
+    def __init__(self, read=False, write=False, delete=False, list=False,  # pylint: disable=redefined-builtin
+                 add=False, create=False, update=False, process=False):
         self.read = read
         self.write = write
         self.delete = delete
-        self.delete_previous_version = delete_previous_version
-        self.permanent_delete = kwargs.pop('permanent_delete', False)
         self.list = list
         self.add = add
         self.create = create
         self.update = update
         self.process = process
-        self.tag = kwargs.pop('tag', False)
-        self.filter_by_tags = kwargs.pop('filter_by_tags', False)
-        self.set_immutability_policy = kwargs.pop('set_immutability_policy', False)
         self._str = (('r' if self.read else '') +
-                     ('w' if self.write else '') +
+                     ('w' if  self.write else '') +
                      ('d' if self.delete else '') +
-                     ('x' if self.delete_previous_version else '') +
-                     ('y' if self.permanent_delete else '') +
                      ('l' if self.list else '') +
                      ('a' if self.add else '') +
                      ('c' if self.create else '') +
                      ('u' if self.update else '') +
-                     ('p' if self.process else '') +
-                     ('f' if self.filter_by_tags else '') +
-                     ('t' if self.tag else '') +
-                     ('i' if self.set_immutability_policy else '')
-                     )
+                     ('p' if self.process else ''))
 
     def __str__(self):
         return self._str
@@ -380,30 +354,22 @@ class AccountSasPermissions(object):
 
         :param str permission: Specify permissions in
             the string with the first letter of the word.
-        :return: An AccountSasPermissions object
-        :rtype: ~azure.storage.filedatalake.AccountSasPermissions
+        :return: A AccountSasPermissions object
+        :rtype: ~azure.storage.blob.AccountSasPermissions
         """
         p_read = 'r' in permission
         p_write = 'w' in permission
         p_delete = 'd' in permission
-        p_delete_previous_version = 'x' in permission
-        p_permanent_delete = 'y' in permission
         p_list = 'l' in permission
         p_add = 'a' in permission
         p_create = 'c' in permission
         p_update = 'u' in permission
         p_process = 'p' in permission
-        p_tag = 't' in permission
-        p_filter_by_tags = 'f' in permission
-        p_set_immutability_policy = 'i' in permission
-        parsed = cls(read=p_read, write=p_write, delete=p_delete, delete_previous_version=p_delete_previous_version,
-                     list=p_list, add=p_add, create=p_create, update=p_update, process=p_process, tag=p_tag,
-                     filter_by_tags=p_filter_by_tags, set_immutability_policy=p_set_immutability_policy,
-                     permanent_delete=p_permanent_delete)
 
+        parsed = cls(p_read, p_write, p_delete, p_list, p_add, p_create, p_update, p_process)
+        parsed._str = permission # pylint: disable = protected-access
         return parsed
 
-
 class Services(object):
     """Specifies the services accessible with the account SAS.
 
