@@ -3,19 +3,13 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=invalid-overridden-method
-from datetime import datetime
-from typing import Any, Dict, Union
-
-from azure.core.exceptions import AzureError, HttpResponseError
-from azure.multiapi.storagev2.blob.v2020_06_12.aio import BlobClient
-from .._serialize import get_api_version
+from azure.storage.blob.aio import BlobClient
 from .._shared.base_client_async import AsyncStorageAccountHostsMixin
 from .._path_client import PathClient as PathClientBase
-from .._models import DirectoryProperties, AccessControlChangeResult, AccessControlChangeFailure, \
-    AccessControlChangeCounters, AccessControlChanges
-from .._generated.aio import AzureDataLakeStorageRESTAPI
+from .._models import DirectoryProperties
+from .._generated.aio import DataLakeStorageClient
 from ._data_lake_lease_async import DataLakeLeaseClient
+from .._generated.models import StorageErrorException
 from .._deserialize import process_storage_error
 from .._shared.policies_async import ExponentialRetry
 
@@ -35,43 +29,16 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         # type: (...) -> None
         kwargs['retry_policy'] = kwargs.get('retry_policy') or ExponentialRetry(**kwargs)
 
-        super(PathClient, self).__init__(account_url,  # pylint: disable=specify-parameter-names-in-call
-                                         file_system_name, path_name,
+        super(PathClient, self).__init__(account_url, file_system_name, path_name, # type: ignore # pylint: disable=specify-parameter-names-in-call
                                          credential=credential,
-                                         **kwargs)  # type: ignore
+                                         **kwargs)
 
         kwargs.pop('_hosts', None)
-
-        self._blob_client = BlobClient(account_url=self._blob_account_url, container_name=file_system_name,
-                                       blob_name=path_name,
-                                       credential=credential,
-                                       _hosts=self._blob_client._hosts,  # pylint: disable=protected-access
-                                       **kwargs)
-
-        self._client = AzureDataLakeStorageRESTAPI(self.url, file_system=file_system_name, path=path_name,
-                                                   pipeline=self._pipeline)
-        self._datalake_client_for_blob_operation = AzureDataLakeStorageRESTAPI(self._blob_client.url,
-                                                                               file_system=file_system_name,
-                                                                               path=path_name,
-                                                                               pipeline=self._pipeline)
-        api_version = get_api_version(kwargs)
-        self._client._config.version = api_version  # pylint: disable=protected-access
-        self._datalake_client_for_blob_operation._config.version = api_version  # pylint: disable=protected-access
-
+        self._blob_client = BlobClient(self._blob_account_url, file_system_name, blob_name=path_name,
+                                       credential=credential, _hosts=self._blob_client._hosts, **kwargs)  # type: ignore # pylint: disable=protected-access
+        self._client = DataLakeStorageClient(self.url, file_system_name, path_name, pipeline=self._pipeline)
         self._loop = kwargs.get('loop', None)
 
-    async def __aexit__(self, *args):
-        await self._blob_client.close()
-        await super(PathClient, self).__aexit__(*args)
-
-    async def close(self):
-        # type: () -> None
-        """ This method is to close the sockets opened by the client.
-        It need not be used when using with a context manager.
-        """
-        await self._blob_client.close()
-        await self.__aexit__()
-
     async def _create(self, resource_type, content_settings=None, metadata=None, **kwargs):
         # type: (...) -> Dict[str, Union[str, datetime]]
         """
@@ -88,9 +55,9 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             Name-value pairs associated with the file/directory as metadata.
         :type metadata: dict(str, str)
         :keyword lease:
-            Required if the file/directory has an active lease. Value can be a DataLakeLeaseClient object
+            Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
         :keyword str umask:
             Optional and only valid if Hierarchical Namespace is enabled for the account.
             When creating a file or directory and the parent folder does not have a default ACL,
@@ -135,25 +102,25 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             **kwargs)
         try:
             return await self._client.path.create(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     async def _delete(self, **kwargs):
-        # type: (**Any) -> Dict[Union[datetime, str]]
+        # type: (bool, **Any) -> None
         """
         Marks the specified path for deletion.
 
         :keyword lease:
             Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
-        :keyword ~datetime.datetime if_modified_since:
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :param ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
             Specify this header to perform the operation only
             if the resource has been modified since the specified time.
-        :keyword ~datetime.datetime if_unmodified_since:
+        :param ~datetime.datetime if_unmodified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
@@ -164,14 +131,14 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword int timeout:
+        :param int timeout:
             The timeout parameter is expressed in seconds.
         :return: None
         """
         options = self._delete_path_options(**kwargs)
         try:
             return await self._client.path.delete(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     async def set_access_control(self, owner=None,  # type: Optional[str]
@@ -209,7 +176,7 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword lease:
             Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -234,7 +201,7 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         options = self._set_access_control_options(owner=owner, group=group, permissions=permissions, acl=acl, **kwargs)
         try:
             return await self._client.path.set_access_control(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     async def get_access_control(self, upn=None,  # type: Optional[bool]
@@ -256,7 +223,7 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword lease:
             Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -281,246 +248,48 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         options = self._get_access_control_options(upn=upn, **kwargs)
         try:
             return await self._client.path.get_properties(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
-    async def set_access_control_recursive(self,
-                                           acl,
-                                           **kwargs):
-        # type: (str, **Any) -> AccessControlChangeResult
-        """
-        Sets the Access Control on a path and sub-paths.
-
-        :param acl:
-            Sets POSIX access control rights on files and directories.
-            The value is a comma-separated list of access control entries. Each
-            access control entry (ACE) consists of a scope, a type, a user or
-            group identifier, and permissions in the format
-            "[scope:][type]:[id]:[permissions]".
-        :type acl: str
-        :keyword func(~azure.storage.filedatalake.AccessControlChanges) progress_hook:
-            Callback where the caller can track progress of the operation
-            as well as collect paths that failed to change Access Control.
-        :keyword str continuation_token:
-            Optional continuation token that can be used to resume previously stopped operation.
-        :keyword int batch_size:
-            Optional. If data set size exceeds batch size then operation will be split into multiple
-            requests so that progress can be tracked. Batch size should be between 1 and 2000.
-            The default when unspecified is 2000.
-        :keyword int max_batches:
-            Optional. Defines maximum number of batches that single change Access Control operation can execute.
-            If maximum is reached before all sub-paths are processed,
-            then continuation token can be used to resume operation.
-            Empty value indicates that maximum number of batches in unbound and operation continues till end.
-        :keyword bool continue_on_failure:
-            If set to False, the operation will terminate quickly on encountering user errors (4XX).
-            If True, the operation will ignore user errors and proceed with the operation on other sub-entities of
-            the directory.
-            Continuation token will only be returned when continue_on_failure is True in case of user errors.
-            If not set the default value is False for this.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :return: A summary of the recursive operations, including the count of successes and failures,
-            as well as a continuation token in case the operation was terminated prematurely.
-        :rtype: :~azure.storage.filedatalake.AccessControlChangeResult`
-        :raises ~azure.core.exceptions.AzureError:
-            User can restart the operation using continuation_token field of AzureError if the token is available.
-        """
-        if not acl:
-            raise ValueError("The Access Control List must be set for this operation")
-
-        progress_hook = kwargs.pop('progress_hook', None)
-        max_batches = kwargs.pop('max_batches', None)
-        options = self._set_access_control_recursive_options(mode='set', acl=acl, **kwargs)
-        return await self._set_access_control_internal(options=options, progress_hook=progress_hook,
-                                                       max_batches=max_batches)
-
-    async def update_access_control_recursive(self, acl, **kwargs):
-        # type: (str, **Any) -> AccessControlChangeResult
-        """
-        Modifies the Access Control on a path and sub-paths.
-
-        :param acl:
-            Modifies POSIX access control rights on files and directories.
-            The value is a comma-separated list of access control entries. Each
-            access control entry (ACE) consists of a scope, a type, a user or
-            group identifier, and permissions in the format
-            "[scope:][type]:[id]:[permissions]".
-        :type acl: str
-        :keyword func(~azure.storage.filedatalake.AccessControlChanges) progress_hook:
-            Callback where the caller can track progress of the operation
-            as well as collect paths that failed to change Access Control.
-        :keyword str continuation_token:
-            Optional continuation token that can be used to resume previously stopped operation.
-        :keyword int batch_size:
-            Optional. If data set size exceeds batch size then operation will be split into multiple
-            requests so that progress can be tracked. Batch size should be between 1 and 2000.
-            The default when unspecified is 2000.
-        :keyword int max_batches:
-            Optional. Defines maximum number of batches that single,
-            change Access Control operation can execute.
-            If maximum is reached before all sub-paths are processed,
-            then continuation token can be used to resume operation.
-            Empty value indicates that maximum number of batches in unbound and operation continues till end.
-        :keyword bool continue_on_failure:
-            If set to False, the operation will terminate quickly on encountering user errors (4XX).
-            If True, the operation will ignore user errors and proceed with the operation on other sub-entities of
-            the directory.
-            Continuation token will only be returned when continue_on_failure is True in case of user errors.
-            If not set the default value is False for this.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :return: A summary of the recursive operations, including the count of successes and failures,
-            as well as a continuation token in case the operation was terminated prematurely.
-        :rtype: :~azure.storage.filedatalake.AccessControlChangeResult`
-        :raises ~azure.core.exceptions.AzureError:
-            User can restart the operation using continuation_token field of AzureError if the token is available.
-        """
-        if not acl:
-            raise ValueError("The Access Control List must be set for this operation")
-
-        progress_hook = kwargs.pop('progress_hook', None)
-        max_batches = kwargs.pop('max_batches', None)
-        options = self._set_access_control_recursive_options(mode='modify', acl=acl, **kwargs)
-        return await self._set_access_control_internal(options=options, progress_hook=progress_hook,
-                                                       max_batches=max_batches)
-
-    async def remove_access_control_recursive(self,
-                                              acl,
-                                              **kwargs):
-        # type: (str, **Any) -> AccessControlChangeResult
-        """
-        Removes the Access Control on a path and sub-paths.
-
-        :param acl:
-            Removes POSIX access control rights on files and directories.
-            The value is a comma-separated list of access control entries. Each
-            access control entry (ACE) consists of a scope, a type, and a user or
-            group identifier in the format "[scope:][type]:[id]".
-        :type acl: str
-        :keyword func(~azure.storage.filedatalake.AccessControlChanges) progress_hook:
-            Callback where the caller can track progress of the operation
-            as well as collect paths that failed to change Access Control.
-        :keyword str continuation_token:
-            Optional continuation token that can be used to resume previously stopped operation.
-        :keyword int batch_size:
-            Optional. If data set size exceeds batch size then operation will be split into multiple
-            requests so that progress can be tracked. Batch size should be between 1 and 2000.
-            The default when unspecified is 2000.
-        :keyword int max_batches:
-            Optional. Defines maximum number of batches that single change Access Control operation can execute.
-            If maximum is reached before all sub-paths are processed,
-            then continuation token can be used to resume operation.
-            Empty value indicates that maximum number of batches in unbound and operation continues till end.
-        :keyword bool continue_on_failure:
-            If set to False, the operation will terminate quickly on encountering user errors (4XX).
-            If True, the operation will ignore user errors and proceed with the operation on other sub-entities of
-            the directory.
-            Continuation token will only be returned when continue_on_failure is True in case of user errors.
-            If not set the default value is False for this.
-        :keyword int timeout:
-            The timeout parameter is expressed in seconds.
-        :return: A summary of the recursive operations, including the count of successes and failures,
-            as well as a continuation token in case the operation was terminated prematurely.
-        :rtype: :~azure.storage.filedatalake.AccessControlChangeResult`
-        :raises ~azure.core.exceptions.AzureError:
-            User can restart the operation using continuation_token field of AzureError if the token is available.
-        """
-        if not acl:
-            raise ValueError("The Access Control List must be set for this operation")
-
-        progress_hook = kwargs.pop('progress_hook', None)
-        max_batches = kwargs.pop('max_batches', None)
-        options = self._set_access_control_recursive_options(mode='remove', acl=acl, **kwargs)
-        return await self._set_access_control_internal(options=options, progress_hook=progress_hook,
-                                                       max_batches=max_batches)
-
-    async def _set_access_control_internal(self, options, progress_hook, max_batches=None):
-        try:
-            continue_on_failure = options.get('force_flag')
-            total_directories_successful = 0
-            total_files_success = 0
-            total_failure_count = 0
-            batch_count = 0
-            last_continuation_token = None
-            current_continuation_token = None
-            continue_operation = True
-            while continue_operation:
-                headers, resp = await self._client.path.set_access_control_recursive(**options)
-
-                # make a running tally so that we can report the final results
-                total_directories_successful += resp.directories_successful
-                total_files_success += resp.files_successful
-                total_failure_count += resp.failure_count
-                batch_count += 1
-                current_continuation_token = headers['continuation']
-
-                if current_continuation_token is not None:
-                    last_continuation_token = current_continuation_token
-
-                if progress_hook is not None:
-                    await progress_hook(AccessControlChanges(
-                        batch_counters=AccessControlChangeCounters(
-                            directories_successful=resp.directories_successful,
-                            files_successful=resp.files_successful,
-                            failure_count=resp.failure_count,
-                        ),
-                        aggregate_counters=AccessControlChangeCounters(
-                            directories_successful=total_directories_successful,
-                            files_successful=total_files_success,
-                            failure_count=total_failure_count,
-                        ),
-                        batch_failures=[AccessControlChangeFailure(
-                            name=failure.name,
-                            is_directory=failure.type == 'DIRECTORY',
-                            error_message=failure.error_message) for failure in resp.failed_entries],
-                        continuation=last_continuation_token))
-
-                # update the continuation token, if there are more operations that cannot be completed in a single call
-                max_batches_satisfied = (max_batches is not None and batch_count == max_batches)
-                continue_operation = bool(current_continuation_token) and not max_batches_satisfied
-                options['continuation'] = current_continuation_token
-
-            # currently the service stops on any failure, so we should send back the last continuation token
-            # for the user to retry the failed updates
-            # otherwise we should just return what the service gave us
-            return AccessControlChangeResult(counters=AccessControlChangeCounters(
-                directories_successful=total_directories_successful,
-                files_successful=total_files_success,
-                failure_count=total_failure_count),
-                continuation=last_continuation_token
-                if total_failure_count > 0 and not continue_on_failure else current_continuation_token)
-        except HttpResponseError as error:
-            error.continuation_token = last_continuation_token
-            process_storage_error(error)
-        except AzureError as error:
-            error.continuation_token = last_continuation_token
-            raise error
-
-    async def _rename_path(self, rename_source, **kwargs):
-        # type: (str, **Any) -> Dict[str, Any]
+    async def _rename_path(self, rename_source,
+                           **kwargs):
+        # type: (**Any) -> Dict[str, Any]
         """
         Rename directory or file
 
         :param rename_source: The value must have the following format: "/{filesystem}/{path}".
         :type rename_source: str
-        :keyword ~azure.storage.filedatalake.ContentSettings content_settings:
-            ContentSettings object used to set path properties.
-        :keyword source_lease: A lease ID for the source path. If specified,
+        :param source_lease: A lease ID for the source path. If specified,
             the source path must have an active lease and the leaase ID must
             match.
-        :paramtype source_lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
-        :keyword lease:
+        :type source_lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :param ~azure.storage.filedatalake.ContentSettings content_settings:
+            ContentSettings object used to set path properties.
+        :param lease:
             Required if the file/directory has an active lease. Value can be a LeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
-        :keyword ~datetime.datetime if_modified_since:
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
+        :param str umask: Optional and only valid if Hierarchical Namespace is enabled for the account.
+            When creating a file or directory and the parent folder does not have a default ACL,
+            the umask restricts the permissions of the file or directory to be created.
+            The resulting permission is given by p & ^u, where p is the permission and u is the umask.
+            For example, if p is 0777 and u is 0057, then the resulting permission is 0720.
+            The default permission is 0777 for a directory and 0666 for a file. The default umask is 0027.
+            The umask must be specified in 4-digit octal notation (e.g. 0766).
+        :param permissions: Optional and only valid if Hierarchical Namespace
+            is enabled for the account. Sets POSIX access permissions for the file
+            owner, the file owning group, and others. Each class may be granted
+            read, write, or execute permission.  The sticky bit is also supported.
+            Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are
+            supported.
+        :type permissions: str
+        :param ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
             Specify this header to perform the operation only
             if the resource has been modified since the specified time.
-        :keyword ~datetime.datetime if_unmodified_since:
+        :param ~datetime.datetime if_unmodified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
@@ -531,13 +300,13 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions match_condition:
             The match condition to use upon the etag.
-        :keyword ~datetime.datetime source_if_modified_since:
+        :param ~datetime.datetime source_if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
             Specify this header to perform the operation only
             if the resource has been modified since the specified time.
-        :keyword ~datetime.datetime source_if_unmodified_since:
+        :param ~datetime.datetime source_if_unmodified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
             If a date is passed in without timezone info, it is assumed to be UTC.
@@ -548,15 +317,16 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             and act according to the condition specified by the `match_condition` parameter.
         :keyword ~azure.core.MatchConditions source_match_condition:
             The source match condition to use upon the etag.
-        :keyword int timeout:
+        :param int timeout:
             The timeout parameter is expressed in seconds.
+        :return:
         """
         options = self._rename_path_options(
             rename_source,
             **kwargs)
         try:
             return await self._client.path.create(**options)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     async def _get_path_properties(self, **kwargs):
@@ -567,7 +337,7 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword lease:
             Required if the directory or file has an active lease. Value can be a DataLakeLeaseClient object
             or the lease ID as a string.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
+        :type lease: ~azure.storage.filedatalake.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -588,22 +358,21 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :rtype: DirectoryProperties or FileProperties
+
+        .. admonition:: Example:
+
+            .. literalinclude:: ../tests/test_blob_samples_common.py
+                :start-after: [START get_blob_properties]
+                :end-before: [END get_blob_properties]
+                :language: python
+                :dedent: 8
+                :caption: Getting the properties for a file/directory.
         """
         path_properties = await self._blob_client.get_blob_properties(**kwargs)
+        path_properties.__class__ = DirectoryProperties
         return path_properties
 
-    async def _exists(self, **kwargs):
-        # type: (**Any) -> bool
-        """
-        Returns True if a path exists and returns False otherwise.
-
-        :kwarg int timeout:
-            The timeout parameter is expressed in seconds.
-        :returns: boolean
-        """
-        return await self._blob_client.exists(**kwargs)
-
-    async def set_metadata(self, metadata,  # type: Dict[str, str]
+    async def set_metadata(self, metadata=None,  # type: Optional[Dict[str, str]]
                            **kwargs):
         # type: (...) -> Dict[str, Union[str, datetime]]
         """Sets one or more user-defined name-value pairs for the specified
@@ -615,10 +384,9 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
             A dict containing name-value pairs to associate with the file system as
             metadata. Example: {'category':'test'}
         :type metadata: dict[str, str]
-        :keyword lease:
+        :keyword str or ~azure.storage.filedatalake.DataLakeLeaseClient lease:
             If specified, set_file_system_metadata only succeeds if the
             file system's lease is active and matches this ID.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -639,6 +407,15 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :returns: file system-updated property dict (Etag and last modified).
+
+        .. admonition:: Example:
+
+            .. literalinclude:: ../samples/test_file_system_samples.py
+                :start-after: [START set_file_system_metadata]
+                :end-before: [END set_file_system_metadata]
+                :language: python
+                :dedent: 12
+                :caption: Setting metadata on the container.
         """
         return await self._blob_client.set_blob_metadata(metadata=metadata, **kwargs)
 
@@ -651,10 +428,9 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
 
         :param ~azure.storage.filedatalake.ContentSettings content_settings:
             ContentSettings object used to set file/directory properties.
-        :keyword lease:
+        :keyword str or ~azure.storage.filedatalake.DataLakeLeaseClient lease:
             If specified, set_file_system_metadata only succeeds if the
             file system's lease is active and matches this ID.
-        :paramtype lease: ~azure.storage.filedatalake.aio.DataLakeLeaseClient or str
         :keyword ~datetime.datetime if_modified_since:
             A DateTime value. Azure expects the date value passed in to be UTC.
             If timezone is included, any non-UTC datetimes will be converted to UTC.
@@ -716,7 +492,7 @@ class PathClient(AsyncStorageAccountHostsMixin, PathClientBase):
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :returns: A DataLakeLeaseClient object, that can be run in a context manager.
-        :rtype: ~azure.storage.filedatalake.aio.DataLakeLeaseClient
+        :rtype: ~azure.storage.filedatalake.DataLakeLeaseClient
 
         .. admonition:: Example:
 
