@@ -3,28 +3,43 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=invalid-overridden-method
+
 import asyncio
 import sys
-import warnings
 from io import BytesIO
 from itertools import islice
-from typing import AsyncIterator
+import warnings
 
-from azure.core.exceptions import HttpResponseError, ResourceModifiedError
-from .._download import _ChunkDownloader
+from azure.core.exceptions import HttpResponseError
+from .._shared.encryption import decrypt_blob
 from .._shared.request_handlers import validate_and_format_range_headers
 from .._shared.response_handlers import process_storage_error, parse_length_from_content_range
+from .._download import process_range_and_offset, _ChunkDownloader
 
 
-async def process_content(data):
+async def process_content(data, start_offset, end_offset, encryption):
     if data is None:
         raise ValueError("Response cannot be None.")
-
     try:
-        return data.response.body()
+        content = data.response.body()
     except Exception as error:
         raise HttpResponseError(message="Download stream interrupted.", response=data.response, error=error)
+    if encryption.get('key') is not None or encryption.get('resolver') is not None:
+        try:
+            return decrypt_blob(
+                encryption.get('required'),
+                encryption.get('key'),
+                encryption.get('resolver'),
+                content,
+                start_offset,
+                end_offset,
+                data.response.headers)
+        except Exception as error:
+            raise HttpResponseError(
+                message="Decryption failed.",
+                response=data.response,
+                error=error)
+    return content
 
 
 class _AsyncChunkDownloader(_ChunkDownloader):
@@ -52,9 +67,6 @@ class _AsyncChunkDownloader(_ChunkDownloader):
         else:
             self.progress_total += length
 
-        if self.progress_hook:
-            await self.progress_hook(self.progress_total, self.total_size)
-
     async def _write_to_stream(self, chunk_data, chunk_start):
         if self.stream_lock:
             async with self.stream_lock:  # pylint: disable=not-async-context-manager
@@ -64,9 +76,12 @@ class _AsyncChunkDownloader(_ChunkDownloader):
             self.stream.write(chunk_data)
 
     async def _download_chunk(self, chunk_start, chunk_end):
+        download_range, offset = process_range_and_offset(
+            chunk_start, chunk_end, chunk_end, self.encryption_options
+        )
         range_header, range_validation = validate_and_format_range_headers(
-            chunk_start,
-            chunk_end,
+            download_range[0],
+            download_range[1],
             check_content_md5=self.validate_content
         )
         try:
@@ -78,21 +93,18 @@ class _AsyncChunkDownloader(_ChunkDownloader):
                 download_stream_current=self.progress_total,
                 **self.request_options
             )
-            if response.properties.etag != self.etag:
-                raise ResourceModifiedError(message="The file has been modified while downloading.")
         except HttpResponseError as error:
             process_storage_error(error)
 
-        chunk_data = await process_content(response)
+        chunk_data = await process_content(response, offset[0], offset[1], self.encryption_options)
         return chunk_data
 
 
 class _AsyncChunkIterator(object):
-    """Async iterator for chunks in blob download stream."""
+    """Async iterator for chunks in file download stream."""
 
-    def __init__(self, size, content, downloader, chunk_size):
+    def __init__(self, size, content, downloader):
         self.size = size
-        self._chunk_size = chunk_size
         self._current_content = content
         self._iter_downloader = downloader
         self._iter_chunks = None
@@ -112,35 +124,21 @@ class _AsyncChunkIterator(object):
         if self._complete:
             raise StopAsyncIteration("Download complete")
         if not self._iter_downloader:
-            # cut the data obtained from initial GET into chunks
-            if len(self._current_content) > self._chunk_size:
-                return self._get_chunk_data()
+            # If no iterator was supplied, the download completed with
+            # the initial GET, so we just return that data
             self._complete = True
             return self._current_content
 
         if not self._iter_chunks:
             self._iter_chunks = self._iter_downloader.get_chunk_offsets()
+        else:
+            try:
+                chunk = next(self._iter_chunks)
+            except StopIteration:
+                raise StopAsyncIteration("Download complete")
+            self._current_content = await self._iter_downloader.yield_chunk(chunk)
 
-        # initial GET result still has more than _chunk_size bytes of data
-        if len(self._current_content) >= self._chunk_size:
-            return self._get_chunk_data()
-
-        try:
-            chunk = next(self._iter_chunks)
-            self._current_content += await self._iter_downloader.yield_chunk(chunk)
-        except StopIteration:
-            self._complete = True
-            # it's likely that there some data left in self._current_content
-            if self._current_content:
-                return self._current_content
-            raise StopAsyncIteration("Download complete")
-
-        return self._get_chunk_data()
-
-    def _get_chunk_data(self):
-        chunk_data = self._current_content[: self._chunk_size]
-        self._current_content = self._current_content[self._chunk_size:]
-        return chunk_data
+        return self._current_content
 
 
 class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attributes
@@ -156,7 +154,7 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         The properties of the file being downloaded. If only a range of the data is being
         downloaded, this will be reflected in the properties.
     :ivar int size:
-        The size of the total data in the stream. This will be the byte range if specified,
+        The size of the total data in the stream. This will be the byte range if speficied,
         otherwise the total size of the file.
     """
 
@@ -167,6 +165,7 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
             start_range=None,
             end_range=None,
             validate_content=None,
+            encryption_options=None,
             max_concurrency=1,
             name=None,
             path=None,
@@ -187,14 +186,13 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         self._max_concurrency = max_concurrency
         self._encoding = encoding
         self._validate_content = validate_content
-        self._progress_hook = kwargs.pop('progress_hook', None)
+        self._encryption_options = encryption_options or {}
         self._request_options = kwargs
         self._location_mode = None
         self._download_complete = False
         self._current_content = None
         self._file_size = None
         self._response = None
-        self._etag = None
 
         # The service only provides transactional MD5s for chunks under 4MB.
         # If validate_content is on, get only self.MAX_CHUNK_GET_SIZE for the first
@@ -207,7 +205,9 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         else:
             initial_request_end = initial_request_start + self._first_get_size - 1
 
-        self._initial_range = (initial_request_start, initial_request_end)
+        self._initial_range, self._initial_offset = process_range_and_offset(
+            initial_request_start, initial_request_end, self._end_range, self._encryption_options
+        )
 
     def __len__(self):
         return self.size
@@ -238,7 +238,12 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         if self.size == 0:
             self._current_content = b""
         else:
-            self._current_content = await process_content(self._response)
+            self._current_content = await process_content(
+                self._response,
+                self._initial_offset[0],
+                self._initial_offset[1],
+                self._encryption_options
+            )
 
     async def _initial_request(self):
         range_header, range_validation = validate_and_format_range_headers(
@@ -264,9 +269,6 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
             # Parse the total file size and adjust the download size if ranges
             # were specified
             self._file_size = parse_length_from_content_range(response.properties.content_range)
-            if self._file_size is None:
-                raise ValueError("Required Content-Range response header is missing or malformed.")
-
             if self._end_range is not None:
                 # Use the length unless it is over the end of the file
                 self.size = min(self._file_size, self._end_range - self._start_range + 1)
@@ -276,7 +278,7 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
                 self.size = self._file_size
 
         except HttpResponseError as error:
-            if self._start_range is None and error.response and error.response.status_code == 416:
+            if self._start_range is None and error.response.status_code == 416:
                 # Get range will fail on an empty file. If the user did not
                 # request a range, do a regular get request in order to get
                 # any properties.
@@ -299,14 +301,12 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         # If file size is large, download the rest of the file in chunks.
         if response.properties.size == self.size:
             self._download_complete = True
-        self._etag = response.properties.etag
         return response
 
     def chunks(self):
-        # type: () -> AsyncIterator[bytes]
         """Iterate over chunks in the download stream.
 
-        :rtype: AsyncIterator[bytes]
+        :rtype: Iterable[bytes]
         """
         if self.size == 0 or self._download_complete:
             iter_downloader = None
@@ -325,22 +325,19 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
                 stream=None,
                 parallel=False,
                 validate_content=self._validate_content,
+                encryption_options=self._encryption_options,
                 use_location=self._location_mode,
-                etag=self._etag,
                 **self._request_options)
         return _AsyncChunkIterator(
             size=self.size,
             content=self._current_content,
-            downloader=iter_downloader,
-            chunk_size=self._config.max_chunk_get_size
-        )
+            downloader=iter_downloader)
 
     async def readall(self):
-        # type: () -> bytes
         """Download the contents of this file.
 
         This operation is blocking until all data is downloaded.
-        :rtype: bytes
+        :rtype: bytes or str
         """
         stream = BytesIO()
         await self.readinto(stream)
@@ -350,12 +347,10 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         return data
 
     async def content_as_bytes(self, max_concurrency=1):
-        """DEPRECATED: Download the contents of this file.
+        """Download the contents of this file.
 
         This operation is blocking until all data is downloaded.
 
-        This method is deprecated, use func:`readall` instead.
-
         :keyword int max_concurrency:
             The number of parallel connections with which to download.
         :rtype: bytes
@@ -368,12 +363,10 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
         return await self.readall()
 
     async def content_as_text(self, max_concurrency=1, encoding="UTF-8"):
-        """DEPRECATED: Download the contents of this file, and decode as text.
+        """Download the contents of this file, and decode as text.
 
         This operation is blocking until all data is downloaded.
 
-        This method is deprecated, use func:`readall` instead.
-
         :keyword int max_concurrency:
             The number of parallel connections with which to download.
         :param str encoding:
@@ -412,9 +405,6 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
 
         # Write the content to the user stream
         stream.write(self._current_content)
-        if self._progress_hook:
-            await self._progress_hook(len(self._current_content), self.size)
-
         if self._download_complete:
             return self.size
 
@@ -433,9 +423,8 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
             stream=stream,
             parallel=parallel,
             validate_content=self._validate_content,
+            encryption_options=self._encryption_options,
             use_location=self._location_mode,
-            progress_hook=self._progress_hook,
-            etag=self._etag,
             **self._request_options)
 
         dl_tasks = downloader.get_chunk_offsets()
@@ -462,8 +451,6 @@ class StorageStreamDownloader(object):  # pylint: disable=too-many-instance-attr
     async def download_to_stream(self, stream, max_concurrency=1):
         """Download the contents of this file to a stream.
 
-        This method is deprecated, use func:`readinto` instead.
-
         :param stream:
             The stream to download to. This can be an open file-handle,
             or any writable stream. The stream must be seekable if the download
