@@ -5,42 +5,41 @@
 # --------------------------------------------------------------------------
 
 import functools
-import warnings
 from typing import (  # pylint: disable=unused-import
-    Any, Dict, List, Optional,
+    Union, Optional, Any, IO, Iterable, AnyStr, Dict, List, Tuple,
     TYPE_CHECKING)
-from urllib.parse import urlparse, quote, unquote
+try:
+    from urllib.parse import urlparse, quote, unquote
+except ImportError:
+    from urlparse import urlparse # type: ignore
+    from urllib2 import quote, unquote # type: ignore
 
 import six
-from azure.core.exceptions import HttpResponseError
+
 from azure.core.paging import ItemPaged
 from azure.core.tracing.decorator import distributed_trace
-
 from ._shared.base_client import StorageAccountHostsMixin, parse_connection_str, parse_query
 from ._shared.request_handlers import add_metadata_headers, serialize_iso
 from ._shared.response_handlers import (
     process_storage_error,
     return_response_headers,
     return_headers_and_deserialized)
-from ._generated import AzureQueueStorage
-from ._generated.models import SignedIdentifier, QueueMessage as GenQueueMessage
-from ._deserialize import deserialize_queue_properties, deserialize_queue_creation
-from ._encryption import StorageEncryptionMixin
 from ._message_encoding import NoEncodePolicy, NoDecodePolicy
+from ._deserialize import deserialize_queue_properties, deserialize_queue_creation
+from ._generated import AzureQueueStorage, VERSION
+from ._generated.models import StorageErrorException, SignedIdentifier
+from ._generated.models import QueueMessage as GenQueueMessage
 from ._models import QueueMessage, AccessPolicy, MessagesPaged
-from ._serialize import get_api_version
 
 if TYPE_CHECKING:
+    from datetime import datetime
+    from azure.core.pipeline.policies import HTTPPolicy
     from ._models import QueueProperties
 
 
-class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
+class QueueClient(StorageAccountHostsMixin):
     """A client to interact with a specific Queue.
 
-    For more optional configuration, please click
-    `here <https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/storage/azure-storage-queue
-    #optional-configuration>`_.
-
     :param str account_url:
         The URL to the storage account. In order to create a client given the full URI to the queue,
         use the :func:`from_queue_url` classmethod.
@@ -48,22 +47,17 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
     :type queue_name: str
     :param credential:
         The credentials with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-        an account shared access key, or an instance of a TokenCredentials class from azure.identity.
-        If the resource URI already contains a SAS token, this will be ignored in favor of an explicit credential
-        - except in the case of AzureSasCredential, where the conflicting SAS tokens will raise a ValueError.
-        If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-        should be the storage account key.
+        account URL already has a SAS token. The value can be a SAS token string, an account
+        shared access key, or an instance of a TokenCredentials class from azure.identity.
     :keyword str api_version:
-        The Storage API version to use for requests. Default value is the most recent service version that is
-        compatible with the current SDK. Setting to an older version may result in reduced feature compatibility.
+        The Storage API version to use for requests. Default value is '2019-07-07'.
+        Setting to an older version may result in reduced feature compatibility.
     :keyword str secondary_hostname:
         The hostname of the secondary endpoint.
-    :keyword message_encode_policy: The encoding policy to use on outgoing messages.
+    :keyword encode_policy: The encoding policy to use on outgoing messages.
         Default is not to encode messages. Other options include :class:`TextBase64EncodePolicy`,
         :class:`BinaryBase64EncodePolicy` or `None`.
-    :keyword message_decode_policy: The decoding policy to use on incoming messages.
+    :keyword decode_policy: The decoding policy to use on incoming messages.
         Default value is not to decode messages. Other options include :class:`TextBase64DecodePolicy`,
         :class:`BinaryBase64DecodePolicy` or `None`.
 
@@ -79,7 +73,7 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
     def __init__(
             self, account_url,  # type: str
             queue_name,  # type: str
-            credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
+            credential=None,  # type: Optional[Any]
             **kwargs  # type: Any
         ):
         # type: (...) -> None
@@ -104,9 +98,8 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
 
         self._config.message_encode_policy = kwargs.get('message_encode_policy', None) or NoEncodePolicy()
         self._config.message_decode_policy = kwargs.get('message_decode_policy', None) or NoDecodePolicy()
-        self._client = AzureQueueStorage(self.url, base_url=self.url, pipeline=self._pipeline)
-        self._client._config.version = get_api_version(kwargs)  # pylint: disable=protected-access
-        self._configure_encryption(kwargs)
+        self._client = AzureQueueStorage(self.url, pipeline=self._pipeline)
+        self._client._config.version = kwargs.get('api_version', VERSION)  # pylint: disable=protected-access
 
     def _format_url(self, hostname):
         """Format the endpoint URL according to the current location
@@ -122,24 +115,15 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
             self._query_str)
 
     @classmethod
-    def from_queue_url(cls,
-                       queue_url,  # type: str
-                       credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
-                       **kwargs  # type: Any
-                       ):
-        # type: (...) -> QueueClient
+    def from_queue_url(cls, queue_url, credential=None, **kwargs):
+        # type: (str, Optional[Any], Any) -> QueueClient
         """A client to interact with a specific Queue.
 
         :param str queue_url: The full URI to the queue, including SAS token if used.
         :param credential:
             The credentials with which to authenticate. This is optional if the
-            account URL already has a SAS token. The value can be a SAS token string,
-            an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-            an account shared access key, or an instance of a TokenCredentials class from azure.identity.
-            If the resource URI already contains a SAS token, this will be ignored in favor of an explicit credential
-            - except in the case of AzureSasCredential, where the conflicting SAS tokens will raise a ValueError.
-            If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-            should be the storage account key.
+            account URL already has a SAS token. The value can be a SAS token string, an account
+            shared access key, or an instance of a TokenCredentials class from azure.identity.
         :returns: A queue client.
         :rtype: ~azure.storage.queue.QueueClient
         """
@@ -171,10 +155,10 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
     def from_connection_string(
             cls, conn_str,  # type: str
             queue_name,  # type: str
-            credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
+            credential=None,  # type: Any
             **kwargs  # type: Any
-     ):
-        # type: (...) -> QueueClient
+        ):
+        # type: (...) -> None
         """Create QueueClient from a Connection String.
 
         :param str conn_str:
@@ -184,12 +168,8 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         :param credential:
             The credentials with which to authenticate. This is optional if the
             account URL already has a SAS token, or the connection string already has shared
-            access key values. The value can be a SAS token string,
-            an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-            an account shared access key, or an instance of a TokenCredentials class from azure.identity.
-            Credentials provided here will take precedence over those in the connection string.
-            If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-            should be the storage account key.
+            access key values. The value can be a SAS token string, an account shared access
+            key, or an instance of a TokenCredentials class from azure.identity.
         :returns: A queue client.
         :rtype: ~azure.storage.queue.QueueClient
 
@@ -210,7 +190,7 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
 
     @distributed_trace
     def create_queue(self, **kwargs):
-        # type: (Any) -> None
+        # type: (Optional[Any]) -> None
         """Creates a new queue in the storage account.
 
         If a queue with the same name already exists, the operation fails with
@@ -246,12 +226,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 headers=headers,
                 cls=deserialize_queue_creation,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
     def delete_queue(self, **kwargs):
-        # type: (Any) -> None
+        # type: (Optional[Any]) -> None
         """Deletes the specified queue and any messages it contains.
 
         When a queue is successfully deleted, it is immediately marked for deletion
@@ -278,12 +258,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         timeout = kwargs.pop('timeout', None)
         try:
             self._client.queue.delete(timeout=timeout, **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
     def get_queue_properties(self, **kwargs):
-        # type: (Any) -> QueueProperties
+        # type: (Optional[Any]) -> QueueProperties
         """Returns all user-defined metadata for the specified queue.
 
         The data returned does not include the queue's list of messages.
@@ -308,17 +288,14 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 timeout=timeout,
                 cls=deserialize_queue_properties,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
         response.name = self.queue_name
         return response # type: ignore
 
     @distributed_trace
-    def set_queue_metadata(self,
-                           metadata=None,  # type: Optional[Dict[str, Any]]
-                           **kwargs  # type: Any
-                           ):
-        # type: (...) -> None
+    def set_queue_metadata(self, metadata=None, **kwargs):
+        # type: (Optional[Dict[str, Any]], Optional[Any]) -> None
         """Sets user-defined metadata on the specified queue.
 
         Metadata is associated with the queue as name-value pairs.
@@ -348,12 +325,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 headers=headers,
                 cls=return_response_headers,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
     def get_queue_access_policy(self, **kwargs):
-        # type: (Any) -> Dict[str, AccessPolicy]
+        # type: (Optional[Any]) -> Dict[str, Any]
         """Returns details about any stored access policies specified on the
         queue that may be used with Shared Access Signatures.
 
@@ -368,16 +345,13 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 timeout=timeout,
                 cls=return_headers_and_deserialized,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
         return {s.id: s.access_policy or AccessPolicy() for s in identifiers}
 
     @distributed_trace
-    def set_queue_access_policy(self,
-                                signed_identifiers,  # type: Dict[str, AccessPolicy]
-                                **kwargs  # type: Any
-                                ):
-        # type: (...) -> None
+    def set_queue_access_policy(self, signed_identifiers, **kwargs):
+        # type: (Dict[str, AccessPolicy], Optional[Any]) -> None
         """Sets stored access policies for the queue that may be used with Shared
         Access Signatures.
 
@@ -426,15 +400,14 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 queue_acl=signed_identifiers or None,
                 timeout=timeout,
                 **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
-    def send_message(
-            self,
-            content,  # type: Any
-            **kwargs  # type: Any
-    ):
+    def send_message( # type: ignore
+            self, content, # type: Any
+            **kwargs  # type: Optional[Any]
+        ):
         # type: (...) -> QueueMessage
         """Adds a new message to the back of the message queue.
 
@@ -484,25 +457,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         visibility_timeout = kwargs.pop('visibility_timeout', None)
         time_to_live = kwargs.pop('time_to_live', None)
         timeout = kwargs.pop('timeout', None)
-        try:
-            self._config.message_encode_policy.configure(
-                require_encryption=self.require_encryption,
-                key_encryption_key=self.key_encryption_key,
-                resolver=self.key_resolver_function,
-                encryption_version=self.encryption_version)
-        except TypeError:
-            warnings.warn(
-                "TypeError when calling message_encode_policy.configure. \
-                It is likely missing the encryption_version parameter. \
-                Consider updating your encryption information/implementation. \
-                Retrying without encryption_version."
-            )
-            self._config.message_encode_policy.configure(
-                require_encryption=self.require_encryption,
-                key_encryption_key=self.key_encryption_key,
-                resolver=self.key_resolver_function)
-        encoded_content = self._config.message_encode_policy(content)
-        new_message = GenQueueMessage(message_text=encoded_content)
+        self._config.message_encode_policy.configure(
+            require_encryption=self.require_encryption,
+            key_encryption_key=self.key_encryption_key,
+            resolver=self.key_resolver_function)
+        content = self._config.message_encode_policy(content)
+        new_message = GenQueueMessage(message_text=content)
 
         try:
             enqueued = self._client.messages.enqueue(
@@ -511,84 +471,26 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 message_time_to_live=time_to_live,
                 timeout=timeout,
                 **kwargs)
-            queue_message = QueueMessage(content=content)
+            queue_message = QueueMessage(content=new_message.message_text)
             queue_message.id = enqueued[0].message_id
             queue_message.inserted_on = enqueued[0].insertion_time
             queue_message.expires_on = enqueued[0].expiration_time
             queue_message.pop_receipt = enqueued[0].pop_receipt
             queue_message.next_visible_on = enqueued[0].time_next_visible
             return queue_message
-        except HttpResponseError as error:
-            process_storage_error(error)
-
-    @distributed_trace
-    def receive_message(self, **kwargs):
-        # type: (Any) -> QueueMessage
-        """Removes one message from the front of the queue.
-
-        When the message is retrieved from the queue, the response includes the message
-        content and a pop_receipt value, which is required to delete the message.
-        The message is not automatically deleted from the queue, but after it has
-        been retrieved, it is not visible to other clients for the time interval
-        specified by the visibility_timeout parameter.
-
-        If the key-encryption-key or resolver field is set on the local service object, the message will be
-        decrypted before being returned.
-
-        :keyword int visibility_timeout:
-            If not specified, the default value is 0. Specifies the
-            new visibility timeout value, in seconds, relative to server time.
-            The value must be larger than or equal to 0, and cannot be
-            larger than 7 days. The visibility timeout of a message cannot be
-            set to a value later than the expiry time. visibility_timeout
-            should be set to a value smaller than the time-to-live value.
-        :keyword int timeout:
-            The server timeout, expressed in seconds.
-        :return:
-            Returns a message from the Queue.
-        :rtype: ~azure.storage.queue.QueueMessage
-
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/queue_samples_message.py
-                :start-after: [START receive_one_message]
-                :end-before: [END receive_one_message]
-                :language: python
-                :dedent: 12
-                :caption: Receive one message from the queue.
-        """
-        visibility_timeout = kwargs.pop('visibility_timeout', None)
-        timeout = kwargs.pop('timeout', None)
-        self._config.message_decode_policy.configure(
-            require_encryption=self.require_encryption,
-            key_encryption_key=self.key_encryption_key,
-            resolver=self.key_resolver_function)
-        try:
-            message = self._client.messages.dequeue(
-                number_of_messages=1,
-                visibilitytimeout=visibility_timeout,
-                timeout=timeout,
-                cls=self._config.message_decode_policy,
-                **kwargs
-            )
-            wrapped_message = QueueMessage._from_generated(  # pylint: disable=protected-access
-                message[0]) if message != [] else None
-            return wrapped_message
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
     def receive_messages(self, **kwargs):
-        # type: (Any) -> ItemPaged[QueueMessage]
+        # type: (Optional[Any]) -> ItemPaged[QueueMessage]
         """Removes one or more messages from the front of the queue.
 
         When a message is retrieved from the queue, the response includes the message
         content and a pop_receipt value, which is required to delete the message.
         The message is not automatically deleted from the queue, but after it has
         been retrieved, it is not visible to other clients for the time interval
-        specified by the visibility_timeout parameter. The iterator will continuously
-        fetch messages until the queue is empty or max_messages is reached (if max_messages
-        is set).
+        specified by the visibility_timeout parameter.
 
         If the key-encryption-key or resolver field is set on the local service object, the messages will be
         decrypted before being returned.
@@ -598,28 +500,15 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
             messages to retrieve from the queue, up to a maximum of 32. If
             fewer are visible, the visible messages are returned. By default,
             a single message is retrieved from the queue with this operation.
-            `by_page()` can be used to provide a page iterator on the AsyncItemPaged if messages_per_page is set.
-            `next()` can be used to get the next page.
-        .. admonition:: Example:
-
-            .. literalinclude:: ../samples/queue_samples_message.py
-                :start-after: [START receive_messages_listing]
-                :end-before: [END receive_messages_listing]
-                :language: python
-                :dedent: 12
-                :caption: List pages and corresponding messages from the queue.
-
         :keyword int visibility_timeout:
-            If not specified, the default value is 30. Specifies the
+            If not specified, the default value is 0. Specifies the
             new visibility timeout value, in seconds, relative to server time.
-            The value must be larger than or equal to 1, and cannot be
+            The value must be larger than or equal to 0, and cannot be
             larger than 7 days. The visibility timeout of a message cannot be
             set to a value later than the expiry time. visibility_timeout
             should be set to a value smaller than the time-to-live value.
         :keyword int timeout:
             The server timeout, expressed in seconds.
-        :keyword int max_messages:
-            An integer that specifies the maximum number of messages to retrieve from the queue.
         :return:
             Returns a message iterator of dict-like Message objects.
         :rtype: ~azure.core.paging.ItemPaged[~azure.storage.queue.QueueMessage]
@@ -636,7 +525,6 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         messages_per_page = kwargs.pop('messages_per_page', None)
         visibility_timeout = kwargs.pop('visibility_timeout', None)
         timeout = kwargs.pop('timeout', None)
-        max_messages = kwargs.pop('max_messages', None)
         self._config.message_decode_policy.configure(
             require_encryption=self.require_encryption,
             key_encryption_key=self.key_encryption_key,
@@ -649,22 +537,13 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 cls=self._config.message_decode_policy,
                 **kwargs
             )
-            if max_messages is not None and messages_per_page is not None:
-                if max_messages < messages_per_page:
-                    raise ValueError("max_messages must be greater or equal to messages_per_page")
-            return ItemPaged(command, results_per_page=messages_per_page,
-                             page_iterator_class=MessagesPaged, max_messages=max_messages)
-        except HttpResponseError as error:
+            return ItemPaged(command, results_per_page=messages_per_page, page_iterator_class=MessagesPaged)
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
-    def update_message(self,
-                       message,  # type: Any
-                       pop_receipt=None,  # type: Optional[str]
-                       content=None,  # type: Optional[Any]
-                       **kwargs  # type: Any
-                       ):
-        # type: (...) -> QueueMessage
+    def update_message(self, message, pop_receipt=None, content=None, **kwargs):
+        # type: (Any, Optional[str], Optional[Any], Any) -> QueueMessage
         """Updates the visibility timeout of a message. You can also use this
         operation to update the contents of a message.
 
@@ -731,25 +610,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         if receipt is None:
             raise ValueError("pop_receipt must be present")
         if message_text is not None:
-            try:
-                self._config.message_encode_policy.configure(
-                    self.require_encryption,
-                    self.key_encryption_key,
-                    self.key_resolver_function,
-                    encryption_version=self.encryption_version)
-            except TypeError:
-                warnings.warn(
-                    "TypeError when calling message_encode_policy.configure. \
-                    It is likely missing the encryption_version parameter. \
-                    Consider updating your encryption information/implementation. \
-                    Retrying without encryption_version."
-                )
-                self._config.message_encode_policy.configure(
-                    self.require_encryption,
-                    self.key_encryption_key,
-                    self.key_resolver_function)
-            encoded_message_text = self._config.message_encode_policy(message_text)
-            updated = GenQueueMessage(message_text=encoded_message_text)
+            self._config.message_encode_policy.configure(
+                self.require_encryption,
+                self.key_encryption_key,
+                self.key_resolver_function)
+            message_text = self._config.message_encode_policy(message_text)
+            updated = GenQueueMessage(message_text=message_text)
         else:
             updated = None # type: ignore
         try:
@@ -769,15 +635,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
             new_message.pop_receipt = response['popreceipt']
             new_message.next_visible_on = response['time_next_visible']
             return new_message
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
-    def peek_messages(self,
-                      max_messages=None,  # type: Optional[int]
-                      **kwargs  # type: Any
-                      ):
-        # type: (...) -> List[QueueMessage]
+    def peek_messages(self, max_messages=None, **kwargs):
+        # type: (Optional[int], Optional[Any]) -> List[QueueMessage]
         """Retrieves one or more messages from the front of the queue, but does
         not alter the visibility of the message.
 
@@ -830,12 +693,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
             for peeked in messages:
                 wrapped_messages.append(QueueMessage._from_generated(peeked))  # pylint: disable=protected-access
             return wrapped_messages
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
     def clear_messages(self, **kwargs):
-        # type: (Any) -> None
+        # type: (Optional[Any]) -> None
         """Deletes all messages from the specified queue.
 
         :keyword int timeout:
@@ -853,16 +716,12 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
         timeout = kwargs.pop('timeout', None)
         try:
             self._client.messages.clear(timeout=timeout, **kwargs)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
-    def delete_message(self,
-                       message,  # type: Any
-                       pop_receipt=None,  # type: Optional[str]
-                       **kwargs  # type: Any
-                       ):
-        # type: (...) -> None
+    def delete_message(self, message, pop_receipt=None, **kwargs):
+        # type: (Any, Optional[str], Any) -> None
         """Deletes the specified message.
 
         Normally after a client retrieves a message with the receive messages operation,
@@ -910,5 +769,5 @@ class QueueClient(StorageAccountHostsMixin, StorageEncryptionMixin):
                 queue_message_id=message_id,
                 **kwargs
             )
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
