@@ -13,15 +13,14 @@ try:
 except ImportError:
     from urlparse import urlparse # type: ignore
 
-from azure.core.exceptions import HttpResponseError
 from azure.core.paging import ItemPaged
 from azure.core.pipeline import Pipeline
 from azure.core.tracing.decorator import distributed_trace
 from ._shared.models import LocationMode
 from ._shared.base_client import StorageAccountHostsMixin, TransportWrapper, parse_connection_str, parse_query
 from ._shared.response_handlers import process_storage_error
-from ._generated import AzureQueueStorage
-from ._generated.models import StorageServiceProperties
+from ._generated import AzureQueueStorage, VERSION
+from ._generated.models import StorageServiceProperties, StorageErrorException
 
 from ._models import (
     QueuePropertiesPaged,
@@ -51,18 +50,13 @@ class QueueServiceClient(StorageAccountHostsMixin):
     For operations relating to a specific queue, a client for this entity
     can be retrieved using the :func:`~get_queue_client` function.
 
-    For more optional configuration, please click
-    `here <https://github.com/Azure/azure-sdk-for-python/tree/master/sdk/storage/azure-storage-queue
-    #optional-configuration>`_.
-
     :param str account_url:
         The URL to the queue service endpoint. Any other entities included
         in the URL path (e.g. queue) will be discarded. This URL can be optionally
         authenticated with a SAS token.
     :param credential:
         The credentials with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential from azure.core.credentials, an account
+        account URL already has a SAS token. The value can be a SAS token string, an account
         shared access key, or an instance of a TokenCredentials class from azure.identity.
     :keyword str api_version:
         The Storage API version to use for requests. Default value is '2019-07-07'.
@@ -108,8 +102,7 @@ class QueueServiceClient(StorageAccountHostsMixin):
         self._query_str, credential = self._format_query_string(sas_token, credential)
         super(QueueServiceClient, self).__init__(parsed_url, service='queue', credential=credential, **kwargs)
         self._client = AzureQueueStorage(self.url, pipeline=self._pipeline)
-        default_api_version = self._client._config.version  # pylint: disable=protected-access
-        self._client._config.version = kwargs.get('api_version', default_api_version)  # pylint: disable=protected-access
+        self._client._config.version = kwargs.get('api_version', VERSION)  # pylint: disable=protected-access
 
     def _format_url(self, hostname):
         """Format the endpoint URL according to the current location
@@ -130,8 +123,7 @@ class QueueServiceClient(StorageAccountHostsMixin):
         :param credential:
             The credentials with which to authenticate. This is optional if the
             account URL already has a SAS token, or the connection string already has shared
-            access key values. The value can be a SAS token string,
-            an instance of a AzureSasCredential from azure.core.credentials, an account shared access
+            access key values. The value can be a SAS token string, an account shared access
             key, or an instance of a TokenCredentials class from azure.identity.
         :returns: A Queue service client.
         :rtype: ~azure.storage.queue.QueueClient
@@ -182,7 +174,7 @@ class QueueServiceClient(StorageAccountHostsMixin):
             stats = self._client.service.get_statistics( # type: ignore
                 timeout=timeout, use_location=LocationMode.SECONDARY, **kwargs)
             return service_stats_deserialize(stats)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -210,7 +202,7 @@ class QueueServiceClient(StorageAccountHostsMixin):
         try:
             service_props = self._client.service.get_properties(timeout=timeout, **kwargs) # type: ignore
             return service_properties_deserialize(service_props)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -266,7 +258,7 @@ class QueueServiceClient(StorageAccountHostsMixin):
         )
         try:
             return self._client.service.set_properties(props, timeout=timeout, **kwargs) # type: ignore
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
