@@ -3,45 +3,50 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-# pylint: disable=invalid-overridden-method
 
 import functools
 from typing import (  # pylint: disable=unused-import
-    Any, Dict, List, Optional, Union,
+    Union, Optional, Any, Iterable, Dict, List,
     TYPE_CHECKING)
+try:
+    from urllib.parse import urlparse # pylint: disable=unused-import
+except ImportError:
+    from urlparse import urlparse # type: ignore
 
 from azure.core.async_paging import AsyncItemPaged
-from azure.core.exceptions import HttpResponseError
-from azure.core.pipeline import AsyncPipeline
 from azure.core.tracing.decorator import distributed_trace
+from azure.core.pipeline import AsyncPipeline
 from azure.core.tracing.decorator_async import distributed_trace_async
 
-from .._serialize import get_api_version
-from .._shared.base_client_async import AsyncStorageAccountHostsMixin, AsyncTransportWrapper
 from .._shared.policies_async import ExponentialRetry
+from .._queue_service_client import QueueServiceClient as QueueServiceClientBase
 from .._shared.models import LocationMode
+from .._shared.base_client_async import AsyncStorageAccountHostsMixin, AsyncTransportWrapper
 from .._shared.response_handlers import process_storage_error
+from .._generated.version import VERSION
 from .._generated.aio import AzureQueueStorage
-from .._generated.models import StorageServiceProperties
-from .._encryption import StorageEncryptionMixin
+from .._generated.models import StorageServiceProperties, StorageErrorException
+
+from ._models import QueuePropertiesPaged
+from ._queue_client_async import QueueClient
 from .._models import (
     service_stats_deserialize,
     service_properties_deserialize,
 )
-from .._queue_service_client import QueueServiceClient as QueueServiceClientBase
-from ._models import QueuePropertiesPaged
-from ._queue_client_async import QueueClient
 
 if TYPE_CHECKING:
+    from datetime import datetime
+    from azure.core.configuration import Configuration
+    from azure.core.pipeline.policies import HTTPPolicy
     from .._models import (
-        CorsRule,
-        Metrics,
         QueueProperties,
         QueueAnalyticsLogging,
+        Metrics,
+        CorsRule,
     )
 
 
-class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase, StorageEncryptionMixin):
+class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase):
     """A client to interact with the Queue Service at the account level.
 
     This client provides operations to retrieve and configure the account properties
@@ -55,16 +60,11 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
         authenticated with a SAS token.
     :param credential:
         The credentials with which to authenticate. This is optional if the
-        account URL already has a SAS token. The value can be a SAS token string,
-        an instance of a AzureSasCredential or AzureNamedKeyCredential from azure.core.credentials,
-        an account shared access key, or an instance of a TokenCredentials class from azure.identity.
-        If the resource URI already contains a SAS token, this will be ignored in favor of an explicit credential
-        - except in the case of AzureSasCredential, where the conflicting SAS tokens will raise a ValueError.
-        If using an instance of AzureNamedKeyCredential, "name" should be the storage account name, and "key"
-        should be the storage account key.
+        account URL already has a SAS token. The value can be a SAS token string, an account
+        shared access key, or an instance of a TokenCredentials class from azure.identity.
     :keyword str api_version:
-        The Storage API version to use for requests. Default value is the most recent service version that is
-        compatible with the current SDK. Setting to an older version may result in reduced feature compatibility.
+        The Storage API version to use for requests. Default value is '2019-07-07'.
+        Setting to an older version may result in reduced feature compatibility.
     :keyword str secondary_hostname:
         The hostname of the secondary endpoint.
 
@@ -87,7 +87,7 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
 
     def __init__(
             self, account_url,  # type: str
-            credential=None,  # type: Optional[Union[str, Dict[str, str], AzureNamedKeyCredential, AzureSasCredential, "TokenCredential"]] # pylint: disable=line-too-long
+            credential=None,  # type: Optional[Any]
             **kwargs  # type: Any
         ):
         # type: (...) -> None
@@ -98,10 +98,9 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
             credential=credential,
             loop=loop,
             **kwargs)
-        self._client = AzureQueueStorage(self.url, base_url=self.url, pipeline=self._pipeline, loop=loop) # type: ignore
-        self._client._config.version = get_api_version(kwargs)  # pylint: disable=protected-access
+        self._client = AzureQueueStorage(url=self.url, pipeline=self._pipeline, loop=loop) # type: ignore
+        self._client._config.version = kwargs.get('api_version', VERSION)  # pylint: disable=protected-access
         self._loop = loop
-        self._configure_encryption(kwargs)
 
     @distributed_trace_async
     async def get_service_stats(self, **kwargs):
@@ -134,7 +133,7 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
             stats = await self._client.service.get_statistics( # type: ignore
                 timeout=timeout, use_location=LocationMode.SECONDARY, **kwargs)
             return service_stats_deserialize(stats)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace_async
@@ -162,7 +161,7 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
         try:
             service_props = await self._client.service.get_properties(timeout=timeout, **kwargs) # type: ignore
             return service_properties_deserialize(service_props)
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace_async
@@ -218,7 +217,7 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
         )
         try:
             return await self._client.service.set_properties(props, timeout=timeout, **kwargs) # type: ignore
-        except HttpResponseError as error:
+        except StorageErrorException as error:
             process_storage_error(error)
 
     @distributed_trace
@@ -380,6 +379,6 @@ class QueueServiceClient(AsyncStorageAccountHostsMixin, QueueServiceClientBase,
         return QueueClient(
             self.url, queue_name=queue_name, credential=self.credential,
             key_resolver_function=self.key_resolver_function, require_encryption=self.require_encryption,
-            encryption_version=self.encryption_version, key_encryption_key=self.key_encryption_key,
-            api_version=self.api_version, _pipeline=_pipeline, _configuration=self._config,
-            _location_mode=self._location_mode, _hosts=self._hosts, **kwargs)
+            key_encryption_key=self.key_encryption_key, api_version=self.api_version, _pipeline=_pipeline,
+            _configuration=self._config, _location_mode=self._location_mode,
+            _hosts=self._hosts, loop=self._loop, **kwargs)
